#!/usr/bin/perl

use strict;
use lib  qw {blib/lib};
use vars qw /$VERSION/;

use Regexp::Common;
use Config;

$^W = 1;

($VERSION) = q $Revision: 1.3 $ =~ /[\d.]+/;

BEGIN {
    if ($] < 5.006) {
        print "1..1\n";
        print "ok 1\n";
        exit;
    }
}

my $count;

my $palindrome = qr /^$RE{lingua}{palindrome}$/;
my $fail       = qr /^$RE{lingua}{palindrome}{-chars => '\d'}$/;
my $keep       = qr /^$RE{lingua}{palindrome}{-keep}$/;

sub mess {print ++ $count, " - $_ (@_)\n"}

sub pass {print     "ok "; &mess}
sub fail {print "not ok "; &mess}

my (@passes, @entries, @failures);
while (<DATA>) {
    chomp;
    last unless /\S/;
    push @passes => $_;
}
while (<DATA>) {
    chomp;
    last unless /\S/;
    push @entries => $_;
}
while (<DATA>) {
    chomp;
    push @failures => $_;
}
push @failures => " ", "";

my $max = 1 + 2 * @failures + 3 * (@passes + 3 * grep {!/^[<>] .*:$/} @entries);

print "1..$max\n";

print "not " unless defined $Regexp::Common::lingua::VERSION;
print "ok ", ++ $count, ' - $Regexp::Common::lingua::VERSION', "\n";

# print "$fail\n"; exit;

foreach (@passes) {
    /$palindrome/ ? pass "match"       : fail "no match";
    /$keep/       ? $1 eq $_           ? pass "match; keep"
                                       : fail "match ($1); keep"
                                       : fail "no match; keep";
    /$fail/       ? fail "match; fail" : pass "no match; fail";
}

foreach (@failures) {
    /$palindrome/ ? fail "match"       : pass "no match";
    /$keep/       ? fail "match; keep" : pass "no match; keep";
}

foreach my $entry (@entries) {
    if ($entry =~ /^> (.*):/) {
        $palindrome = qr /^$RE{lingua}{palindrome}{-chars => $1}$/;
        $keep       = qr /^$RE{lingua}{palindrome}{-chars => $1}{-keep}$/;
        next;
    }
    if ($entry =~ /^< (.*):/) {
        $fail       = qr /^$RE{lingua}{palindrome}{-chars => $1}$/;
        next;
    }
    local $_ = $entry;
    /$palindrome/ ? fail "match"       : pass "no match";
    /$keep/       ? fail "match; keep" : pass "no match; keep";
    /$fail/       ? fail "match; fail" : pass "no match; fail";
    local $_ = $entry . reverse $entry;
    /$palindrome/ ? pass "match"       : fail "no match";
    /$keep/       ? $1 eq $_           ? pass "match; keep"
                                       : fail "match ($1); keep"
                                       : fail "no match; keep";
    /$fail/       ? fail "match; fail" : pass "no match; fail";
    local $_ = reverse ($entry) . substr $entry, 1;
    /$palindrome/ ? pass "match"       : fail "no match";
    /$keep/       ? $1 eq $_           ? pass "match; keep"
                                       : fail "match ($1); keep"
                                       : fail "no match; keep";
    /$fail/       ? fail "match; fail" : pass "no match; fail";
}



=pod

 $Log: test_lingua_palindrome.t,v $
 Revision 1.3  2003/01/16 11:03:10  abigail
 Added version checks.

 Revision 1.2  2003/01/01 19:05:37  abigail
 More and better tests

 Revision 1.1  2003/01/01 17:05:26  abigail
 Tests for palindromes


=cut

__DATA__
aha
ara
bib
bob
boob
civic
daad
dad
deed
did
dood
dud
ebbe
egge
eke
ene
ere
etste
ewe
eye
gag
gezeg
gig
goog
huh
jij
kaak
kajak
kak
kazak
keek
kek
kik
kok
kook
lal
lel
lepel
level
lil
lol
lul
madam
mam
meeneem
mem
mom
mum
nebben
neen
negen
neggen
nekken
nellen
nemen
nepen
neppen
neren
nessen
neten
netten
neven
non
noon
nun
oho
paap
pap
peep
pep
pip
pop
pup
raar
radar
redder
reder
refer
rekker
remmer
renner
reviver
rotator
rotor
sas
sees
serres
sexes
sis
solos
soos
staats
stoots
sus
temet
tit
toot
tot
tut
wow

PIUTKxJCvkOpOxBvruQmprKTDYNqOV
dFoRHgAiRccckElBXx
PsK
XTFKSkawrQQsuKD
tmWcXrlcDugEW
yeCmZ
JAAqwACtbkRsarBjpybH
umO
LY
QVw
VAvmODfTkqmTJUmYYzkHA
KpSWqLprXQVyJoiDcXuyVyHAB
znBVIpTvDNOcTBhSVypB
WkLv
eLwsfcVcyqoGs
ZYdmZzATWjdyXRgTA
JhN
FkOXiJMG
yxaEEJdchJZrrKtE
JeKgmKmXiMjIW
uzwUtNpDwUVHaUYIyBduxxzvDDus
YTOQDW
zyfOaiLuCRJpdnrs
keLTgGMeMuZ
xw
BnjZqDBjuRQIbCvVJzEVsqayDlh
rygXppXPllVfaGzvAhduojwvWbx
kluIZLlChxzdeqvGSbmmXmvlMIRk
KPRTpYlduSsikZxIUnmEIG
VtrXLUVWtXgmCOFEAjgH
EVMmWlNwdDzrMqkFySqu
otAzxcFTJhkclSKBghDFcuHSSen
BhZIEcS
cGUYxCmfuCTCQH
HAUyDGurtVDVYWtCjnwMxZc
gyR
kCQSBDEhyelvHWairVBIb
qbJMLySShEkRGYSDXLGOFSRptqHqXg
EqBvnUMbleUUTBeGrfULjtxbIVUAJ
MHeACRfmkLgfuNoEwCPoxzi
RLOqrJqxPPuIkWIXvSJFMfBIuqQoE
dICuUyYxlSJNTlXFWIGt
ykcPGDWrRXUrCIXFs
DffKtRrXEdt
yhS
FN
EVPkZtkCvIouNgnQmLQdRn
MZYDY
hU
SKzztckuGEzoTRl
oVSLoNhmcTTvGEHuI
iaWzNvqMWhc
ErGKMyrYZVh
sEGlDLZynCtOelatUsP
vrqpKrnthfMDWRjomcUtFqecJm
uMYQuLjAryubLsPYHDRUK
yzmGauaJy
zFMENR
CcGiFcKtEKzNZ
uFQelhUYJTPKhagyyaPvnGq
rroFF
PRsxeLjrkBvfutPutiHVvHd
mxoCJgKdiqlg
qmaReVPEMZgKmmQqCMwBsTtSsNHjyo
ojHUvSyjxVQ
ZSKQIlJh
XFmxneoRmuRDbBbbGhrvsGDbg
tLEfQCkqonBGgbuczkyCEepaIBVlt
OLdosDy
BInCybewxLyta
gbTbhalTWOYhRsTD
MRuJPA
oRNaUEmoMPuIHmLXJmvAQDjVCK
CeexItkHdPZJsFZmUaNexstUzJFf
bbxyDWAglpIPslBlsQwpBdjZHweySE
MfcdXAXaYjcHsBlrfWUs
MhwLUSzsPtkNov
XALVnQokzYv
ssDrePVQYrqWvyN
WjjMGC
bdkCUZqTACLmKauwi
ocfLRQCgsAnVoG
OKYIiQUuWspMGQXlrSQLCvOCFeTxn
NOOqqpthDCUcSiVTMNaP
CuYuyxYCQgDHzDAnUDSOWxBhrAU
NzNPmTkKNEFbHycVnzCBrRQ
HY
VhZBjzMAdWsIhSYTvtigwkPtBbemaO
OlBgJGCwWLKCCrFmzUgkAwhneLrJ
FSErsMFkuaJIRQzSenJZhbXYZVk
AxbIToofilDOlztHKGQlW
AfKFl
sDdMSbA
KCeLxiIzmjqtlDtsfYC
AVqWvjwfxZZgQyooRTVE
SVTNIXZZClBm
XWoAxCGuSxadoPHDdfRcSEqc
zUBUuVNbCTmSKHqHP
xpMnbOvlUkQmcFWy
GFgrCtE
rEZMbxD
ARDUpNJnBlZvUWnyfE
GZYacxFXIJtkQLPRJaPD
yNHWoUeYkBSyjZMVcjcal
kpYyAn
blzoJEolWB
AGhaDsr
cJVPernvpWPqIkvAQeEn
qbUJ
yBJOeVOkZoNOoNxN
nIIDrGwmioEvpFoLbvtjRNAMgCQ
BZUtNVcnGYLYkQUvNoSmBIKaOzJRqF
cvhORavqRbfZTGaTwnw
qZG
JHWnhvOHPPLmKxvkViGYJttZRJUbCj
BvbmwnoItsrPZ
NrlqmddmhasocoBwDRhThQEwAoUoRd
ZyRbDrWnEbBAosAmcBD
ZrKhE
ZJRzPBGYlEjAzkLS
vEazOJ
CzB
BpCHgXKf
IsNlPxDSa
zANfouWF
tMoGm
vkWGtMiXYmaE
HzaJunjf
rEBKYPyymDNlHubeAsUWHD
AjZHhYP
pLPkzYlaZuxflGvjsKCilKbfMj
LdQJuDUDNEJwQNzViBZb
gQwkurLpBbxpSaDXNBPdxAI
HxExNeoTskjYrCIEtsHXEEEuFmWTX
cYaEQxqkGqbhEVanzCKSrGktibLZU
eUVihWcLFUuLHEPANnaq
YhwEUIqqHPK
sDWTaidyGvRMiHLUZRVXqFPJjMRFhy
MYk
DdtbLkdSNcTALaGJMOtqutHrekmS
EACHiYZHJmUFJQqgTKaNXoQmttv
TVOkgvxmGJtAnFDT
UC
uXCQ
CQBkpSoz
QdjyXkaSLhFMXJlmVczmSOXxDIy
AeSiaxuaReiQrtqAgbf
PAeMWisUtcYrE
IEDqdvVXEmmhXvwwPklOL
byIrwmhwkYNuLPOlYaemdhWovlUl
rksNaiDTENPFdQcSDsHze
BnrhTxbyJAPW
CyVPkpsozVFfgeF
CWjeeSsgWXbeoWvalLOPaMS
ZLQHJaFYIok
bLmWkeg
EknecJbgmpfeXYCzltPDMaCO
fv
gDXSMqxzYpmwCFANIplkakp
YImej
SUsUExgpgsd
RfjZBAYViPFKxgXr
TYBBpebjMvCFWzuQFfJoQNSJf
NuCAXtQiGsnRHWpkwXZx
iwEVehXSQg
pLAYJAqzCiDtYQTLYJeN
zJaWkkUcxJ
SthfYNJCDsASgjUYXh
ooskfaiuYlpuMVJfsE
LEApyhQkgReaDiCMyzfHVXSgPpy
JTqIEPDwkhCd
LJtzQ
nRJMQkxUPI
yRuVKKepQpPCradasXEJpCKhugMZ
MMBwEg
szqundrxJjWkpbiQuqcilNstGc
IUDYGtEJXEdissr
SxuMlxILBjua
ddrmcasYrgiTHSX
ipfdpZKc
Xn
HIP
NLOXnWYOutizsom
KpvZIKltFdxhkWKFRfnROqeuW
AwCZXRfbHIXGyehil
eNsXdeKJkPBklSZdgclPCJ
YDNhkEOEESFKhMVNDofeRSFcGm
nzaEcbIYmqQzLpwyGdXXZjwdHWfIf
ILEgMXVxawlAZTeYOysmMEwoFlFs
cWvqygcRaclyrtpReONEBduUTra
mmcTDMvZZYoHyEzoeDjgKRE
ZiKAIpqNEeqdXpnXPKDqtAO
VqjegVoXmEefxpgbpzNFQIDilAkeaj
yDWTguIU
wYtMDrNtXdGckeOhcXwIBHy
UuDqwMDfZY
wfegJHtNOUyA
aozDwgXpkaV
JxElzgSLtV
OmwiWsbrAaKzrRtuvGRCfrSXQcby
VXUmCARCxttfeYJO
dQUncuVQLePlexeZLYkU
AfLXhfeZIjrehJiWUlTSfnAC
nRFvnDjGszVwPpTZ
VeKeyQMSWml
ih
ToWWoDlZCG
tGALHOh
uMYILefILxKTexfZ
uuNSPToxzeicLorEPbHiYwbf
MBXUMBSPciMhcHPPMx
eWWIzXrjCOjHXEwzKTnHPZeCDU
rYYqkAqPzMFTLsTBq
WJQfjTqKyJsCwrs
pzQmSBpvGLzRkceVFOSFhZJONALVsA
YtSKXcsHtLwwaUguLiMsDSHgrLR
aKfphFqBKJiMkKh
WwPmjJFZi
KBFlNhhItaLPpADpcTZxOGKzQtgvs
vIUk
fwQEHVoaodnDenfxOhcZBfcRzoOz
GMHNuCAuccNdxZkZKkoiVKiA
TzJN
jPzTsqVt
yJYvCBFnnXRRrhbgrxoVa
OHhFmPHqQjQxuT
odIQXOU
xyugQEZfowFnhGCUHEoIZZdIpPDSp
yoUOq
XXTIwPax
LIanqAlillqTiHbwNC
lyZpzpTPMaKlYFNM
vbyfCwPmKMeFqtBjcfobOacnWn
yJtZHfihZJjJjoj
JYq
ebDJRNUAIoQaMhzolgLuL
ciWiMg
aWsfcTFGDgHtYGITUtdFxn
kMhLTEVAyGDtwE
IRqpcVTvwtSRORgzhupInyWHhvb
PakBCiaydkrECMICMlZgHSkXq
HzoIOylPRuWLlIGt
COziePFRHMjFVNgMTLJyiBL
neuZIdCiRKYcTysmqRTSZIXr
lMKoaoKqOQoYffLGxruQZq
rUetCKiAxBlhWaDrJUFJbMahVhz
ZWCHeTWiOAGoTDLocW
gsrkRFvy
YQqIYybhGiC
UTSWUh
XuQLGwFXPtYQFCmBzezhYkHNcbHi
XVpJVirTVRPsLb
lzafhxnZvYxxSsyGo
UEOUtP
MqklPbNMTKlaVSKV
KFeSChfyljnwBEQrwJeLMJvLjMzKl
aSJeOrRxngnbzRLI
ysFNYzztgYtXf
JX
eWRkxhSvnOJlFZ
EXDYeNuf
Tf
KgsSINCtpGEATmkiaL
OttcoyAUDzIFAOGly
vsAIEc
tnat
VeIZgHPvXvFnPGDkTgGSQsUlk
WRjPMbxsQxDAVxd
WmyEAvbvfIiZSwCGMYJzkSxcGyYCM
ukCkGiWfilptImqcgUzDLX
gPoKNiININJMejLCQuGsI
PkAfqTFtVoxy
UKwLZVjurRqmfmpIToysJJgv
kdogksDLroP
yKtIQYPMBxhwqusWk
miqbGl
wwYSpVINxOQBwAdmmzrJNAGcfe
bxfZbCKVvUdTuFbBiZjArLivKYScS
De
AkseGuoXcJGrrvTuw
UnVSGOZuFqKkUaKOcGSWgOrL
mvWghIjVNC
HqeQSbFTysiVkMYfCPZqe
OoQeEdMODKiyZZmgGTlBT
swHiPejxrcYtgqOiLyWPmZjKm
dglLHQNAyBnRGPQGjySJkvI
Kqkb
WMyyznjsKNf
OhYkxWkZN
GPULPqLRkCTxmvQmdYXCcByzu
PAarlyIUtW
ianFTlVbSqsNyvuHkYTrFRfKorLpPd
jjHLnYfAOuhpumvj
bWvBRsTUQ
KC
OHgzpPyek
cWq
NITIw
wAKfBJuShkongke
GPHHUvRtvhxOvqgJgLshUgDcW
mjgsz
WveFBbhzkjOSMEUJAu
fD
GOnbgqFPYkBbwej
POXYUOcvPe
fV
OhAJBUTgytlyAoSPLMyMGgBcGur
NaUcVUQUI
AlIYUcBHAbwxgCDM
VJrWuRDparTVSNqpnOZrvhGt
Ki
npMClZYYexqKVrXHZC
uzCEGpUROomcuDpAxRyEssTdAwF
qDHXtRiCSOLfuvihOYMJ
NSstVeacCRewZIYYhKAvisDwRqRq
NZaszlVNyTLf
Om
nHWdQOJpO
IvokHloGlkifvBLMHQAyR
lJjxZDAcTFrHY
sRlDRfydBVThDXmSZklOJnUt
rhvPUTkztHerVfdDTyy
ITXcwlKWzvs
PXNnVnzntWtEC
bxHIIEzZTXOrNAosdcejPkGgvkgUb
ukFcKSLCGZCm
Mo
YKxuUvti
OOvOpDVfpnYIlBvBwNgittEAIfuDw
lbtpvvdNzJNbLeLCAWZgK
tQuHjLGtuXHI
LWJa
qYVFvdcJiAOtcxzoeynTRDiQwSizsr
CsyC
Mafls
uDATnAkUOXTUAJSHCFgDxRuvwn
XpLbVoKahXUluhzC
oJblBeOdNBhvOWykxhokNeobzkRFp
bgxGxgbyZVrJtfwDPwD
gXynwUcwApOQXjtHzTEgklSOyFoM
ibcgqzJlfFPDlXYjyFPW
pCmEANJQjqCMWAIBM
JuojrkqHrYhozOpqAqSPSAdr
AFsbZecBqAxakgAQNfLmapmqy
vatPbML
nkwYkVJVk
HVlLtVXfODbGGFblRYH
AoRxUvDThvzzDvtnCZdxrXlTxtWx
DGpBSmwRGJnEDaYqwSYZGLoH
EzhqRLaGupTQGvep
mVqjINXqyvOOXicPnyrC
KC
MAXTSVZlrwiLR
rZfBPu
uhIvUTDUDIhP
UmaUBpcJxdvOQMXCgiIltAEcIGuc
fRydkcVCmW
mtfGSrUxYUnMXhBApbXdlIkOUgfZRQ
pkqdAYbZMSvG
obKRo
JanoOaj
VnVCROoyRXttO
pVr
kbBVDZqeIqRaNmrKuaFMgyJsgjhtj
MnjnIEVTQfKf
rnMucJzkuxQ
icbUNtHdJ
JL
DlBBzWFtjZsCrvl
ntPghFXWfxWOKJopKBaNFeA
drm
NuRuHElSPJuyubFyqukjuxs
FPZYa
rkIRRGOsmfAhVA
UsfJcfFfUr
vrjFlLkjPnbiyHrDtskwxaMgb
xm
WYtMWHyXGKuvjDtMLrufFMNamYF
hAxZSPCgVrqyjtIbJtgXgi
QiHmj
eyKibP
WKukFRMwre
XBCbjunDogMak
tuP
dqyQEzhxmIOzhbapanYGdbMbEDyxDg
cxKPtShFGRWFBIvRkyU
CeiIFjaPAmmWNAgbAjpIZx
mJHTeWEvfdWJwclSHqeGnxSCz
nU
bSEtXOsrbUBQHQzEDpPzr
FucRwuiEjAQBhCTpKxzKwyTiQlpv
jkTARrqptBlEfimIhQA
nhtQkXPGhxRajiGYqFcgKXV
Zj
NMDSPBUblqnUFcHbbKSIKR
IQXqzOMmFswExRGhIn
auoeztFXkSuOAcEA
ZCpuEYPDgvGbABoapsrciElJE
wLLcyHJHoiLHH
gbddIjWCrsSWhXkFHv
rnMpTbXfMVxwHgnlsqfHuBB
busVXULFmLZb
CapHRzEPXAWqVZjMkVLNSedXPPYDx
hiwlrKIzo
IkSZeUPAOTUtelZuDp
dEiVPtKQAvgncqXDOyGExiDS
HhUOprVmZnHxSD
rlBjncc
SrKgHOaXpUzTWCrzqWlgPOVRoa
RmWLVcbkCSgdWfohdGcXuTiIjCE
zdfXUndWLjkaUhsbXBRSGJVQtwSTp
GfpYxXPXyZrgfcduVfOaIUZcNfcGPH
GgdezEhTwnCv
sZImwzh
krJnBdDtvXJrnZlfmKEqzxGnQQO
OusZEoCbhvnIkGMTZzOKQKt
wZjijTIygHbaYOIkPxZkXTDDXPi
pXlby
uY
XcrpfayJKyJqwpSn
MBVZoFigXnsEtAqCIZiUtvzrIU
rqRXiRjGSSWOMrLlcEzXvpQp
UEISofDWHI
kSZboBLHxTfPfMrooZwCAlGlx
vxuQdfzOOSmcEoiuCAr
nHGOZhXNyQF
AkfLruejk
WkbQvjENkPjtULQwDmQ
PbXncLUvHiGaWPApGkYYZbSrFrVq
TXKsRFPpJnXPctPtBjNIIAYeE
capRoksxZPOlZnJbScFsPbPNTiIS
eCbX
HogWoviuZpDREFha
zravoovIxEZjJlpqZEtbfym
zyIeojiWnaCxhLTTNYdBlEZ
joVCLjBhgNsFzdDXdnffJOhAHR
SjhTdOiYMAMurWgAwdiYgQIehmFWaw
vJuSZQed
lXvvtcvqIidSUVsQqC
zVhAhqeciwCRLcbVI
ccfjqkdmptKgzthizuyeFUxj
RllEuJICDFlpAMOOUxNjLfCiBBi
UMJHyXuoeijpGqeFC
TbBcmQFRWbMMtQdhAVVipzopn
ipSgtEJWrJJYBQXIA
NZmTWq
RubeTIdWghJORYGZKZEtUjTygfZXV
klxiFpnedupjzymVNHnupZZMyX
aNucPpnHKgeMRaMJ
AAhPIYdIGDsLZBBjkf
gnfkWVVXAzvBGUNEDERWb
JmJMKhmrFgoTNj
BjP
AOCimCR
PlqNqmih
ENxHSBxiijRKfoKphuhPletWNGG
mHIPvEFwXdVJNK
RhtlpGKiNkb
LLdAvbDzBvnCXi
FMoYUCVXAoxeFPQUgWxsbUslIDGsvt
daHcjFdOT
lzcMKoiWrNTwxjB
SsnRGFmGUYpgjnRHHvPR
vJNLyvgNwLMpMood
YrknywkvZjvfA
CRGzHcupKubbJLkwhE
kMzIGYHTKcHmthvLmhkORPDSAw
TbuVOBDIfAIeT
aTJXYgzFLiXfnj
fIHhVlQgaeaMtsVVHExfV
yEEQLVvpbEVVjRC
czfPbd
hpGrMLRzeSPQDOen
bqmpN
VY
lHmlufloOsEUgtdVCqkYOk
dcesbFEOjKv
dpAtjnJNYCLENXyDCgHFIUkmp
ADxDjnFvkGdndAlKgr
iMsrEihRKHGbmLHsnIHtFgfLYbFmDW
LF
vlgPBOWaWuVSdiSQ
VvCeFCZb
audwlBStOPSLMdxq
IykklTCOuusE
zNblvRKLgjcwCObcxLegFEdQYUhbR
RiDDkZevQxX
xkANRvynNOtjYuwATHgNuyUVNSSc
hqbjgTbIoCloDHLORRo
YFAkERaWojyOweqNyhwcmxVCSsVXc
dWINXbWnWVTOJQHSBOvOg
UdmHaGX
sUZwYuzKGPJgukbuRxaNrsGX
JNpgbRdTyVKgvDPUgYXThDEY
NZVfEtexUluTmUrnJC
HZLGQsYKFTkZetAWXXhANGcBJgRJS
QnZvgwpqGfZibOxEc
eKCiKAePINhpOtMxJiJOfAkwZY
aWHmcV
UGCUD
wQCZJQgQ
pqHyWyQobsfPmGSAHQPsEQyEEXz
BvkrYOonADMhJjPrpasEUbhvVW
LpKTIsslBdDwYn
TTExbVqDTVQSI
RnliNQsBmNVNalLqcGThZArMEuii
kgGOvsfSNdFCRYHYhxPeKzXd
EQVMxpDtlwwqlJCin
MF
KnBGRLNEPg
mDpGgsEnXhkzvjFfrZFMrqfYtVbS
tJvVxcnkSXBOn
sJsYtzlcLxOxjyoVuVqwI
ASPzvLXiFNhYSLlc
XqqGtpxKRqlHiwHRr
DhWSQpPyiIHgyDcppiuwKLZAgm
XFSCxtlaPrysCU
KhbxMENqwLkVoTTWvnFKVEOoL
ClbnVXLc
jLHyAJB
NGySGj
KngryRJvoASMJninJx
iRYcvxAgHFmzDNrDIgIuoOgSO
okzcqBiscGZNGzXJ
RRnGCAPjHMBFd
MVJjovNrLdHHEeujYhUdmFjO
MNOUrMKMCzHHVm
sZymkEdlLkAHOrdDTYWW
EahPlTYFdmwxJgAcrSThxTNUnyqPc
InDRPOUfQhyUGxhO
qLVJHcsaSJAigWyg
DndPTYISZKwihTUdRUCEpsA
ANjDFESLjdGEmPiLlYkdUhYpHUD
KXCvBPTvneKJtKFUzpUETfPBgkO
fruRwJLFTnGExONySByCiO
myXbclhZvR
addRBtnPmWqMJsmzDHJpWmcfHuPMI
SUcDPb
RkzzLBFNfuYzpelJ
lbyWjyUQUV
OQrXnapWtD
yhP
UFkFQGj
YKzssgDDbXoK
kXSzBIwXURKoaAeHveceHCwMLrH
vrNVubrwlSc
XpskeyAVNrpuKtjZHmxrl
amNTIcraTowODwHKgixsOygF
zOuywBTErewNNtOdvx
bFit
CdjITuxWifuNsCCej
JmcsBvSuZvHKEkJuxudCxHrKnPqia
QlgaCd
fHEtURYeAZIx
XhVxCBwcYdIlFOntgrVjvFmALdN
gsxjzylOqguXuHpEPYXfmV
pTibryj
xKVSvXFDCDXgLXn
lRiQWahEmnuwAigVDqNcBcARYm
oulyjHVXkbMqwJhUYaEPBkN
TiNaJZvtsSG
DnoIDUkSbPjgTwR
zWzNIkqbT
MNodqEjoNvnmiepehAGu
iaZBPhCAxVWoBlkKS
KgtCtVXy
SbXaUvuOldPLopKMKuPchPqfHPzwT
TCGoCUfp
sMDYxNHJrTtqrxqXu
cFilQDysoXpX
omuUHkxMTNPSJtuBPrSBCFMlZHkFyU
pTmFnWKTSCTeujsdXahk
MqyyDYZpgyGZNyIec
vyLpyvUpvI
OYdMtMhusgdBsSklzoweDEbiYgA
zqFit
yLfWFIppq
Te
hIVNzwzgsIXRxDd
imDiJzKCqaEAIuyZfxIRcKQneeGZ
juIThQhPkOMzd
lmvijknlTGlPWK
IYygKjRfiwqGsecBfFuqtRsTnJE
TxkqkMl
diRsrHSfgN
HLEXeutqFSoNqtXXQRJKYtnAgkfdxI
YYhvPNXGmdwpqYLliiiPxPgjO
gsLKFLD
qZrPFZ
FHWTpNIiGuThqwPeEGenVoxNlj
HiFOfrSTNrGgkGE
umTq
UJAHsVIndxINxBhL
DuDXHPlxcZUXlEUHxlQNvbPZN
ZAEjXDoJEVXceyvAPZiEqFAll
MaxwHisoKFqNDxHLUrTrKEvScVhQH
ltQMVhYGRjfBBjutbIrVxQfYg
vAnLgAtracJimEW
PTBqIlDyMRlxZk
kEqGXrBIPhbrciKbnFSBrgEO
bCmYogfDfs
oqPKbkBH
pNaPYikHqqvwqYrznAEsmCDljnDY
cRBREGWtjcjc
RWwXEwMcAzoVZLLFagcQFBB
mZEUJiVpYxpsdsDJBqXNUCYBguOi
GOGnhsMuJh
VPaGLoI
iLBehQE
lwAcXILxWQ
rJOKw
zXFsgi
Tv
YDgFYuRN
rbGzSJjcatKINxvpmFmLmrgkhUN
pVRGZImaUOBwwATIH
tDwibYHfvRp
ljvsnYmzv
JkCCKHEFfiNTMxlUSzqhMpZrIsc
dGNMGStcajQOGDTYFKNTuggxxCDHEK
NlGCuAQMql
In
voDxQeaLhcglfvYK
FBVRAaBJQn
zQZdRQhcqKQeXfLodHiANNQUPcNb
zhRYCLIRitqWimqhRrFivS
kpXivtcEQyeanOCeozec
qWl
hNmhJmOttPUA
oLkcMyDAkWqIJnWjWcwRimjDGCQ
IkdEijnCsEau
wqxTpCQwptuBMbjamucCVOLDK
xoTWLKcoxnIzaiSFqzFnWEHW
Bor
XmvqQJKyuDFUaF
XLupTXffuhw
QZOsXJimfvNQgul
lcGyaFmmqGFv
liVQWxWxbSDQPzIGmyvLQnIjmjXE
WmnlKjk
gTRCTnnrmUXsAsSbvQcQgmzDx
WxWQZoDobGZKJyxzRqhtDSpuYIFZZg
qUIBmbybfRsAGyVRqvbSb
UkpnpkIhFQWozBBNcv
umvlYklCDTBltcjqlRjEZEcJxyGnG
vKJDjsvhpPfUkGWDOlZD
nAwJgngSDRpx
iiSFGOusyhjVrXbrEugkWzrEuhOmTz
fgkCqGVqhbh
vVMbOwcNhVdfCFMrvzQKRvWi
AtIbuyiT
apIsZWWibblwKtrPshTFym
zRqBjiVrNmjepBp
hAYbNGYUFSbirdNhd
ImmVhrKG
SyFHnVKRCW
OdNVXxtExZNCbh
meiJxfCDrupDcWGewPkAKlbrmn
gRJmPSTfgVONQOReDCu
IfumGct
SuAfAjkfCfDoOWxSLADYRzEcB
oBwifvog
dpFpjxeMJpJSZtPjoKWXMFck
MreJJqNn
zmYndWVmfLTuVNHYvgAWKQXJmrs
dOVGOFEU
kbQ
uFVlISWlijgsbspVdDUUbbOurcH
nSxaaIgjcbnvLoqRgQuVAfb
CVMqYMgzOsiX
TbpKwLLAEFFsnpShKsMUSnTyKdRuGI
gRNVAycTCLVwsQ
hPYKPLedOfdNkGVmMdXUUs
xSKfuwZM
tsziNUIqoPpeQMcAD
dxnD
lMicnVYnUDlwYy
VHiJHITvkUDFRbEMXc
fnbnbDTqxt
zWHRTiqkhoVRyOCyBtnDtlpyUNKLHA
LMGRmobYYCxsVHQHFWEf
LEHInaKGQPPVNc
QPeRRwMbJuIS
iMPMPqFVLfHaXUTWHwXNg
hc
bJkMdZRekDNoBOPIsOt
tyuGukXgMl
iiAERggecaSoajFXsGMCOw
QoLZSHCZbbeIeZmMFKFt
ZijjidORJ
Uyxs
qlsZnrDjhiJjySywVNipeyVcg
uJgJKBOOFNuGaadhnXxYWMdPbOfPF
iIEhlwgevrRazGayMqOsDRPAgtMXl
HDRSXtNPJBEDtTSZSaLTLeHWfpx
RzPQgctJ
TFgpjtyEaSIRnFSAg
ORRWaFrpfRgPU
AIRSZ
NdWAkEoNwczO
ILkj
eeYVLfKsHswWXABF
KFf
fjUsLiIid
LpeqtuUUdZWIxVfyeeniQBDAJcmvax
TysyfZlCuaslLNub
VPGVtCpfiySMPHfDN
ptXlWbshgLZG
iGDuYDLN
CkpcLOFlcvkKgtJ
RcAlCKcBbnszLfFDviMgQyl
PUUlYkVWOcXZXgeVryBFxAi
UeicmcmuyrQeZNKBuXO
VjSZXDKUVcZKBlnRbRTBki
DWyLVpidmETbToRNSeOW
pezMPpRDQaSCChRArNQwmJtsgAR
XPiaqAMBDdWnOXcJaSTEmlkHYPnZ
VZADDW
QybIzYAYooKURimvWfVfUmZi
yQAREfWOvPuHZWtnnoDMcLLIyCytxD
YN
SymxwIryGNZIkLpVhNnl
DsoBKPvIqDuHAjSIW
rVdIJoSoEpm
HoiVrhRAyN
YykWOeZPVNbab
NzgGEtXKsyGThFx
NqlW
eYFbBHTPbnfApHUIumRONfKD
zJydRPcZyVrcTvyxbdQwElYpibAYdp
NIKdFFMtwiUUmEfofkmiUWEbwPY
cVPBlOHIJCRakQQVsllGscApk
tetZQcHtgvCZHl
QGKRmjBgPHxFIDCZt
zOIvUPPjIVOwcyPsyDC
Qkcimtksj
HiuEFlOaCozmQtEXTCSZSIBg
igXeGiJURjdRBFxdupbtSRZ
DgFhjqAXFGnbnYqfD
ozwc
XSICAAdRj
hpJkKbJCIFkLOHoAWxtmQlI
RdOWgZgpbJtauzqLeHbbFcwix
StHvAddIPpgCqWEqPL
GEHqajgXqMoj
CWpmXP
artIOApGM
mFcgfR
sJtNddddpI
Dp
LAowqiQTOBeJYaIS
TbnEtDdctcBDYTaXNV
TERYtdUapjTOgDZYri
jSJRRTyqEPfsaNbteTpdU
oOrZKjuXslDIgLQXYxd
HlIdrqnnvwbaOPrBRV
MQ
GVWZRywwptrpPZHtVYjTzqvsj
EC
QBAMVMicV
osDsHWRIfKSyiKaKpqAEJwWe
tQsoLbpLmqVFNjOxMHsy
ftBewlDwP
cHksaQ
fBlyXkwWcPVwsGElTLX
CldpvmrfgYE
PZOsCDOtQzCKrlkGBpbCh
mjTeBGLefNsdjTjKShtRj
BHaxYmbkZTYJ
LyadVUViADGziFipLJtfGlTmpvdqVH
nvirkdHHnPLphoIDGvvcZ
bGcefsyINNremAMOQxRaqihgnBT
RylomkPA
eRTXLTHwgl
ABQvZFffx
Txi
zlzDHcVXJOHbF
uzXCdZKeLWgpsVrJsbrlxDAvbmcUSP
LhuIMbiCkctD
GdyVizpUCOXf
KG
HIEOQpwfQAnAKYuo
HbaLhZpSefoUjKvNiaEdhNzMFTleTC
jvEvTJZvnIvxQga
WYAbP
KpSKokYJNhIyrSqW
eaNuMrnFHrMenuyhiT
SJjVrDWLTYuy
ezQtJDMSpHQGaySpa
LEgGFD
DyJUAXENizeJgEoytqeYgf
PTKgH
kf
QQAb
rRDePmlXMywMxsDBBl
JbjFnpLNchBzRJdvtuaqYj
JQ
LOfpqWlfeRjUlhEwtSDYdNoTDdJQD
mGGshIDcaIzRjvOJwLPGBt
ClluvrvsoeCvjX
qUGprRopujDnBYjJPYtnKMumFYDOmb
dAVWLZIP
DsVUvgs
uSv
FauPimG
UmvgSrngxALZtUWgYdcealEwzBWmCZ
HRaRlwzLYaFy
LjWzj
niYcYlvURrKdiHaqfgxaOECbONYyFZ
fvYnSnQIzJeubRmTFu
VSOdxNQyDNUoeYtMwhWnpAhsC
JuQJ
tvAPEB
heOgycBcjXmOgZig
TGSPudaQvnJQXfTxbsFJLovU
uhtOqoyzEzKuCabNydvYBsn
eniExf
mDwzkkGAqPxSgjAslXgxuwZ
bonFizmOhoKsDnnvbaFYASds
piQ
doQRvFJOJaSOsuNL
seXdgGPypiSeQFNLWjdYeCUema
vzXkGUDkIeKOX
ccEGnZnhh
vY
IAafRVlwpZ
kAWUjpqZmYssZUJLoEpOloRHfhnvsq
sytbhIWy
KzSitaUywdDXRxAZvb
smWQyfIxE
fpfkbgCnNB
etbDINrVUnYmoNaTWBCqFgxE
xBnEmOjUxXUf
naYu
mPPXbbbGglNpSfizPMcBo
zTZKcNPwXmlFqcAD
moZTLPLYphPLsICNAjJieSoLJ
nzCDUBiedtZeLwURjrPUbqP
UwYGpDhjnzShAzyhQszy
NNoqFEZ
fnIUGudGofOrvIlgSrvkDCDWlNH
nhELXspECLXfYIQtDXGBhZN
VhoQpjNfVaDbidvXzVfFFEfHD
lRpnCuCGzuaAICeyOuOGposhmiYcg
WJrlcsAWLtCHlHmkRjP
ywIC
vNcLk
dwIXmPnLtxAgAiMpYzfT
peg
hFbEeGkQ
jPEQrcVQwFgOuZtblhQQIhz
CSexsMIm
rqgCwHcDYBqKCICHNQnXru
FkvGV
XKOKNtSJj
OsmNvngpIvj
NKdjFdXOCuivIE
owycTfHd
DZUOybEAndjzlOQXiexgeaaFicSmiy
LUyGpMQpO
cgLNhNkmkUhHIBcezUFR
RUiNfUcgrNChquNqiJkkK
rWtKBYmoYglywCggSmTcrYXYVNjziQ
CRfaWEMdCqiFUjQy
gey
DkNjalEHd
BJpPEuZASxOrBYEhKVnVHYAcQM
QaIqxBbInAeqtXLlrZvpcSZ
HylihZjvKuHRlNozKf
eEKvZZfwhbpHXVyExWcbDJLVw
MXnAXAdYcbRouRoHOOEWBLQGC
tAauTaIwlqt
zjClSqs
jisNnKcbiBzm
eN
eQazIgEWxFWO
GWCnCIsJmosZYBfYsvd
JGeRp
Mp
eD
iizqLfYgnL
WFiFWkrxqHcMjr
nnlAulFJztoo
uLOKJrruYNVcUcoepWDjQNne
Fv
DDqpRMEsaEfQqeiaoOM
LcxntvIfiRyXCRTE
ltjKZeaoWBjPfUeborROdLLwll
cqHaZVEEEdWqPhtFvzzNtqcAF
JibUpyybUxxqdTYZxsTOLwt
jdvsdjHKWQc
QLeNbRdOthLOUcvaGZwNKBxmI
CKasOg
IYRBNGKCLsHq
PNhhQxODmEjMxiaSLpUc
Hzrw
AVQUXgkwbgsJZZbBHgTvlNCtyo
hbjvZQNnZmtvtejYSgLpdpZpIFSEHZ
TOXniQhXDXjqjbDFPDmqUTH
SWDhQPvrKJaeiCZkaM
AvzyckQ
CpQkNbFcHALfzszjKZkHDYNJVEhV
gTfnViDuIuxZyvzcVZpQbqxrtT
KVynfYt
AsNhsRjQ
iDCFGnLIqidVlARnFYeOUhaMaGcRj
OBpjKECCjaYtopMrYePhaGVVbqsDTF
nuNvWeWRbDiLwIVZYUEwZdiG
KqEmT
jbHNszgAuhqabmiWTfmsVEALtKHFdr
TYEhTeoCQZLeCSC
ttfNcNmDVU
facWxGlFMnBRsuJkHGAlWD
RbBMUHIXfQWPIGnBVtCN
eKCyYHUEZamiOcfHt
YzDWka
kfggrWINPc
UMeUhPNpSRl
oSEOyjqVhBOTcxgJyGp
UghCIHiFOzxyDbY
bIKQrIjoYkaVlCceKDngUof
lhryopOyNyvQfvSiQitowV
PMcbAZtSxDuKJkHmsMuPp
pGqAP
epGJBfPAyUoC
ijUeMmtiegNmgkhtFvBnyxulEEjyIY
eCEYtDVizGWLUczLRrjtvPGeK
iLP
Yj
sCSeCtPmgZoqYjiHyrj
qfpuYgOZyDsQorCn
bXkbyOZYBwYkmYHjZY
CXKCcHgppGnhXHtE
sfMBOYLSxFJegujaOAOv
jWC
riuIucMkTz
YsGfucVXlngtWKPtQddVIhCgX
hfBkwgAqerKMMTPf
BZjWa
XReTtOsfLyp
gUgzrslEeEp
pfsaPDiWaSSrooaiADJG
IpFClLioQCmKlfkjJusWByPqGX
vxXHtIwLkHdAhrXy
ovNdYKVQCgUJrsaqShDlLdBEeHu
QLFSYg
EykKmIKjhiGdAWfuYIUOYRfHTqlJr
aGTXNPB
SVYhTJOjdAHeAsR
jFLZtjcYNrAtwBNfkoha
SFuHaTEaajrNbFeBpEkPN
YcIUURmSfRLoFjJe
eckIDoGgvoqkCEUsqMBLTWkK
pkgwKxLVxQwhQEtAwUesTSogkaIyJf
xYjBxdGcCfLFzXNtAqKRUOJxGKXeJ
AdXpQMeyEIfyr
SfsapxXkpVfbjsmdXUOou
PktrbesqhkyfluVnPwHRugocwvuq
WODAUSbVppQb
efvqfBZLuqYX
ByPHDLvRms
DhHqdSYYJAKMNiHvXPLbl
eKHZtibxzoXlqgILImYzkCctwhku
ecKrqPQqBtIpOEvGEmLIhVFWBuh
FwrCTwpQnnaJOqPhMPBODgzpBmXnH
lDhQ
KRYddvyTyUEWYEahlWtihNOpDrd
rlEBgFsNFsO
nfjVWYpUdgtiab
qHbABOUypLKobEaQyBjp
NsBpkIzckTmqZycZuQBQxkbfmGaj
ZcNRflemqdsWrCnJeFCydBOnJ
qDFnPI
YiImqMoXUdhnNC
nQGnrxzYicL
WmoOUKJi
NeVHWlCPsIW
PzBTPEoraVOMIbZAIzq
iOJqVDGCOPTyZsbsaPlg
Yl
LDuXxKkGOsmcJWUoKbQUuqLrwh
LGDDKUmrXJhhKWXeoYhVGEpwWVX
ddvJjgOYbVQBlpTB
LAZ
pRrxZfIukSORIjJxz
xYaeftKXISpLasaDZkeWbUDReFJS
YElBQsxQdiddncurlxbKVXov
EZTpMtSLMCx
OAcfWphdMFv
Axref
XMwzzoMfHOSMgGMBhVOV
sCnhq
yLYrxgkXDyfMzNqQxvX
UrhwiKxtOLeWD
blM
efhbKlXqBAtnVzfDbf
qnoSZfhTTvgTruFcGAyiGVX
CFsXnsXF
jjqgFrkIpookzlHpKEDPmAtqMP
MzPZ
> [a-z]:
egfmwonzuemqvaowtzf
sodmym
gkblxmpscjku
ixcahttxhoizxuhgdjzxotrgnfg
jppdjf
pohlvqejetby
twpcbrlibkxantpnelaih
cij
rffyopdfzppfwzmbhx
robaaonvxckjnqpdfknx
fcqbqsyedjxatlncvdchqfksfout
hzxniksrmvsultoocdobcx
kjppdkmfygyaauf
xzdhmhhvfpwxgjehfstbkcasjl
mmvopbcfbzr
fjukezncwsercqlyqjgpbkpima
id
eomkbhimruwuqzhkkyweck
igegxjmouxzxnmikfqbibbif
maagnofwyssuwfwmwlpsd
ssiqdlmq
fllwejkyfdybhjtobkq
pfplyojajkhvvvajek
errnkmjtxorjbwevm
cgbedzrbmrgevdcmfgvcoxrclskwau
xfdxghmmgwpimos
floqqbteiyrhrg
djaenjhiaemtwuchhdptuyvkjgczse
pwkrgot
hejyqceif
zsxb
ntgyswuycjukpyfctnrolswgte
ghzfbrfaaxiaxdxtxcnrpqaraocxc
krvnciezavguvra
lbnibfjadnsrujoelulvsvz
dhtmoeluvkgioluxqxqxjuuklqv
chpegzwfglsrvhavleutf
jehyepccqctzrqckdldqjijb
xam
svgwsxqsotoxhbsmtw
qynjdiveoui
vjeoojvl
jgxtdmufxwhtgbqopywxbvtm
dejxnnpazaimpdywoeqjmxupbl
azlgqfajfyu
hgaikr
jiv
lkkhplp
ezrugeakrgaawiiz
faexpmxva
gnpcfiyycaoqydotuania
eyp
nafrzbzmv
voyewcbensmqyrjijdho
jopewovzedkoowqqkkevcks
bdoigtfmqsmcjckkghxsozq
ueckcdnhfwwoshjieci
gdnuhkikfcawayszw
dwnfbgdhrnodfgfxgbe
qaqzaxxkshfuasgcpfvxfuukkctq
nouoo
vskggchnpkdzailquthodwjcqut
biwoywvlepvcklrbnjfgrscjg
jwqjpxirkuaelbljvuihodp
sh
ntvg
taxb
tcgdrjyeltdoycsmkedfrpzod
cqyghkkwezohhstq
yh
jlcmywprdxpncgwjnacqmg
vgbynmxccvuzaegagdkl
dmifxvjozpzo
ozqobubw
aykyvabjckvrwbvmgcd
attrygudunjqjlufznvrvasohf
ixblrjolxay
aokxtxpnnuqchmswkdku
gkkevbvxbtnsmdjftlfr
cnvztjtfbhbbba
yhi
pjpjitpwyesiubzjkmdaiupeph
fgmsfdsmljokjcbddgjihujuxwyyw
dilxiqgpogfx
icupdjsfcxkwaozk
jsfbtqzgjkomgqjloifm
cbejaxokvrzzno
yjzchxeiboxxb
skquqwmpiayqghcwwkdxbsogyoruyc
nuokju
lppgmrwzqbwahkcavtrxqbxymwy
edltdymtxrrnrskdsqnxywi
uisifz
irbyjdlfnikzgqnjxocgzhj
stchqughnkmfyjk
ixmrahvrlaa
staqsibqowtftmekzpdwgogwx
bjewgzksqgsiihsvottbl
tdzugmhsjrr
jqwumbofboemvbzmgxgnxydjocnny
jkfsrydxpmsczopi
cehmrhr
lzlffcbnzortoxqgwprzhaimnyni
ebcrqcpypt
cpmooffmeroijtdrrbqsloegtfr
bfosiocwxzf
kjhpomvqgqkxgulopblnhxpas
abxfbycubxjo
pwfjncmkebmicohtcznlltkgja
dtqkrjdo
wovvcbmlrbbrotlundjvcap
bokgoooergrygqungoqzrcisagxh
ohpqktubiglj
zfqyvmoj
sxsdcapqmivandjmoafkesqqova
rtdqxnqnvmlyhtaczqcexmd
gzkkccbcvkne
yfzgatejtikteoc
omqbldleicqbp
ypupmv
hwarhrpgbpinh
bzdjcproivevqeghgiqwetiix
ihrjqmicseyrzu
qllytsmdtadamuteclmcjfjlwrtgly
sgvsvrwjsuetedscrgcm
zmdjsqyswcoshgalpitibbss
mjcqqbaqffqs
kyzsb
wejbrza
rmo
zbeexlyodfjkxjdztreaanud
fxymvcfkd
bccxnxycfltlntqzsinvbriy
ujurtgmsncr
mdsvxwelfmucbxomhwrxhbntww
mpbdtlef
sudalktqnfgshvcasfonxvcurzz
tebhxpkmxmsbeapaws
mat
kr
laxfakpjczy
ci
bbzu
cwfjrizyp
pwdvqsosrcwyidqmbebscv
cinoblrhd
zm
fmvbpaklqirzbzmayijpgnxtfbaa
dkntlwnumcf
xxcxwp
nwlfitzdygogel
gxreaxdacozozygtvwb
yfeshynawrpirnwfqvnlvrybtplb
scznlsblfsoqodpfgkjxksjjabdwm
zeomoo
yydchhwyrfohophuubi
injsbaybbucj
ygfadvmvfwkap
pbmeiemfvtsnv
idjxknm
eaqqjftivdlxrtx
dprvvhlpnmfhyyqdnbb
etqymseodholdprlp
nveyluvwcecl
mbnutsibz
il
ayvgkcnitnbrfurq
srafwsdfavvunncsldalitg
jd
yqmtfgyk
bljwbjinspydondemavdatk
xukykzuzlhggjlwxhzuofaxnxkgqwl
wodeeqgngmxgrircame
hyhqvyxfkhdevp
enfvj
wkxuhsaoodepc
nouhikzrcleameskywzxqt
ziyutsxssfxifphuqffog
jugywvazfwituamscj
lfifctwzzczjg
novvasapqayldou
fvgzo
xxewgetwmphsbsmfifbdcut
twqidszwrjridsp
rgeywfdfhsqbeznouawnuvdib
lyorcdhf
utjeeqoedustdroylxxkbiapqwtplk
nvbtkbk
gabdsuwbbhpbodecjlkp
dwkpuweeumvpsmmbfslaivzjgmkud
tvofdqgnaplctofjjbzkydhgubkh
jdxpbjkomaqwweasyhcuycldef
oiiyiubvccm
dchubdsxqtt
ocljownxvtedzhrorwvudl
lfvtfahhsritcyfltqapiccmhtsjoj
lcy
sjhdrvgwbzjvgttrocrtqtkszw
jwzqrnduqakbp
tbnbdchbuhcpcrurdewjjxivrkefh
cutuhygqlbviowaerlmkp
mpvfuqvcpnorwhopl
fyxnyyfcjth
vjfrkpzcdlxeqbjchrcgmxkwrs
leldlhskhshkb
rrzdaniafshb
cfxgzkuciukoaakmyjgbtfhcco
lxoxawqwbjsppjxsmvtmoz
kgmunfg
bdugsyvaijoevbexc
crgjnhm
hkybgzav
okprunjevzmutdbcjujupsyl
lwqgmoudexc
ktjnd
wdsmtxrrqpkwxfinzpnxsfisap
ngmwmhfgkwcjglmafwmpspwinjzqeq
skhhfbovrerzjhwyatjrqmwfhnno
mlunmxgaxmrrpk
osxwfibnlziptrxhfsevym
qfesrmgtczldqz
mjejboymq
gdgiu
girkyzvhwibxycorsoyibbr
glhjyaonijv
yghnsoxpmdcwnayh
jkfwoll
zmismkfgpvrfdcjrnrvvoxbvcumx
hxzmdbpdoqotzmikx
zqykzauvnneaeirrkrgogncyktjxsn
ckjjxoapkpdtpxsydtrotlin
efldneanevcifyyrzbk
tahxwczxrrzwxdiizyebx
enegmblwkhszhbpmbpmu
qnicsuarcn
pfydz
rovnniebebijnzhmd
dvmnvkdzfgzlzcm
anmhahftaghlsdoc
zpqedrlhqeorxllrnxhgpm
wrpxylyycwebjcxtxsctyxno
nbywbp
zcszdnbugzfehaaqzccuk
ad
hnpynhxngtasi
cwahpcqqfiulbqqqh
feholmruealbwaapkivbneziqsll
ilmagtsvgsvlitr
xinkvbjua
eemdebt
bxbllbcvqntwrnloifwdipa
iaqgcqidhdb
ktossnvcktfafkor
lfqjjnvbjwlyfohecxoimlvvk
ilspkgmqguerhxeaglljimqg
fnehqxanltxpgbzk
mudgtwscdkputspsk
mhekrrp
niafpfdbrdhwafhhkwo
vr
xzawfkyxcppvilhcnibomwkpula
felqrvfykrtseyfib
uwfdqjjv
egkuukt
qu
hnnirmrodsjjykfmuk
hlvyyujinaqf
tymc
jvumr
eqnaft
wqkmedwxnnropwnpcpclgnzfe
llmwfvuvbnpfdggnakhqzrlg
rtsrlaqoztkqgnjfmhurwefzvgwtmi
tumjwtinowsdmxbng
tnbwqtnghphhlgeoifvpctspsvtyyw
rwcilb
suburcgtaehxyailiskhiktlfh
sazrmzojjqaaosecaygngr
dyqgku
hpyluesgaipzjprzg
sftjesoj
ivtzsdk
hfajegrbjeznotsaxnentfwnytzde
fosygr
jjbu
cwlsztmhpzleths
puwnwfm
iv
cbarsipkzmqntqjxbpfmlyaa
ywwkozmjkimfgrjslzuwvy
advxotzbhntcd
jlfuemunalhximqcgvfnysyajk
rwgrfbozcvbexydhwgbwwxaxu
zrcnyucksgxjjuritgyfeufi
zbjmnbqhjrhlqcgdmxbh
ent
xuazpunfgukd
uitbzqgwijujxqeiwpzknzehhqv
slagjghhbshqdrgdthskrwfcovfxws
vmgnmuzjdiqf
igyynbxi
muqlxxvqltcr
dhajuwvgacoqxgxqdk
sbhrzvsegaljeevkbm
gorvtdjlqyywnuiztahhwrdqcyqy
kshqjoxedutotmtvknnu
pokiurvnpmfdmntflukoihzrsj
sdpkxtaqfhbniv
ynao
nifjffrylxwnhimljqvsexri
cqgvfpssqhjivisnchgmdddx
zdigux
rtwhwhhrxcerfdifyorfyaxmtnx
nvdhqxxjjabvgiprlgl
sokfacikfvmmwhemndtermoubeeluf
isrlhfduy
tm
fisxsfi
ubuesokgphhwvk
xoazlhmmxjvorofvctb
vibtrffmwgef
lcxqsliqfbzrmlxysjcahkahb
caglucgh
bgm
bjgklyusawakfaartvopxdqfb
hhgyiradaewzowhknzvlaptjcvieoa
hwhxiievqgky
kltb
gesomfajdkqrbwjqii
prmh
rslfeacwibqtvzpczwcrjmgmfq
czpnn
nhpheokmaegvruvp
phcsbhtugjwexvixartkemhkcg
egxurdydytambre
bkenejjdphnediyqkabaqawmyjrle
vciazdovxvtrnsei
ljqysjmdiylarioic
qtjzwyznhdluqbtqrg
ikbzemquqecsqfltn
vpmytbqfyusbfjcbjlllpxdlacmh
lefpqmsumksgqnnaoixbtavdyas
tvtdput
csnhggzfiwwfoyqwfmnndrdargtzj
mbydptqddiqdwvqueggcxpyajdure
edahjdlueobdfrgfpmyh
xd
jjadhzbjqywwuvltxm
gxutyeuywxivifv
hpasgoglixvopbpig
djmxhhylyhghdaijbseawbbveqxm
sqltgmbomakgsl
yvfkfko
uw
fwgjjlkvhqbfui
pnqvl
tnagls
peifgxkwvnrglvar
lnbsublnddodsdxh
wlvplsuiqfefjlnxhihxwszqn
yozmygdqpgqcrmbaupho
libajcyaxbfeych
qimhnsomkuczmocr
vqojqnqqkjq
qviwa
jzkwowjzwprrvqcoeybrjvps
ljrz
ibshucuikopmkqstywqanx
jlhxszslllcgmovmcgxrcx
hlqsiqzt
nxbajxdvwjkkbenuxevrtoq
alywkdigmzrtukqjehuzigjs
dqasbmffzipheavqomows
apveqadvnssrwaistbue
bztukrphzuuoahfnribbt
nraviw
gpawyfxsweearboaycwteo
uuqryqjkkvwcbxi
ojqzmhyxhcnmdgsqqslqaudsgchog
bqjhqsvluuznbyesnyqrr
xcuzmueeophw
onnajrhfxmwrrhpulutzrmmi
nuxmtwumdtzkbmrrtampucksdnwfo
wmrqyhryjlttpwi
itpvocvdotbbeegnzpq
tura
vtwjzgluztrrukdglgeiqmvp
ykjxusw
gbrltt
eobzaqyyfyxfzioau
srcdlwbnf
hpjfizubdklukimmxo
hawhteyzebbl
motqscxacv
cku
tdaojsomdyterbfndk
fxtvxgrveptnasiuypjkgltmre
fyygzirv
phnvvbshrdejxucljaqaiauev
qaosklmijljlzjeujowryzogcra
gldmnpjjjjnyoakeoa
dzmpaeanp
znmdigjg
ovsloxpe
vorzxttk
glykqwc
wxyafhjzcgsdr
xogtvpdffbekgmhyzbl
agkuswdneexmhb
aowpifrzna
wer
vrchwdloyegouwsbu
roazoteb
myqeyjfbkzzlmbxosmnenpgl
ekjrofsuxvciszwgjhwawwdzgkbhn
vphicgec
qrwtxv
sxyknujrszrfwevjbbvaabfv
uukup
zxeutuzmhd
ucdudwuqzrzpkrebrkdwdguvpq
sntn
qihthhavw
odkxssimnvpgmjhudahdajbwusf
vshkcy
umjzhzu
runiyxbpwavi
qnxekf
spoxpnmakhwkctyvgdbyhbnwvh
jbjddafnpgfeh
dzedla
mlhwybcsgqiqtfgako
jjxpnhgkhllabjqzrxmzloizucu
vyvhowqxwbpeldmxyowylmungfpoy
jdczlwy
hmvmzekutuusyokqniawixneh
tvwqkacwlfcjpfoxn
rdckbeldv
hapkefqsnuicmyzfuollnjytmuqo
mcgpxbmoftekijmzgqrbaqq
ickrhldzbgtlbylcyfqsofacfk
blfselev
iuwrlq
yk
tobuhrnbayuhltckloefojiz
wsohkffltljwpvjncganbi
fdtnjimdmbeysun
chavgezgcn
ioeobtqgwgkfuywmdpacvfaadqec
aucnu
fzlqvxwvfacaisyjyssirwihxrbm
selsikxrkg
pf
drrhtuwlpalmwfctqaanho
ugblcci
gkoo
nbebpwlhhetaufpostskqbv
vmbsjctyngmk
wezaleqsrr
atpyrhllcjvcspzxzm
dltrdhjdpbdfgvcbxmninvfeuv
ufyqirnqrlhdlplzvt
tgiuifoanwkoujftkgsnpbeiw
nofbhkqclqftvnfgr
hhawdmxaknfmrywtmdwhhsbads
apjsgokslshc
fhyvonzllcdq
vhhpplqstqprdvbu
nvnltlnqsguebedhbt
pbmsuzmilklpmawkfdchwpwtqg
girfbitkxyekp
sywonom
myirqcgdjghgmkpa
qeqsmvumlrfufvibaexhyl
bxoeuccsnotrugmcqhdvptorngc
spxekpiqhhlihwiwscjocniwu
xpfulijnbiayezbpymzahcjbfamok
fov
kuyldhaxxvhgeniuaxtvovjp
rsgxawjtieqfkvgxrd
zun
ldelkwlrkwykbwkaytxnvak
aewdmsnrvvpnlszcivcujaua
kirhtobzfi
grblxbweaejzybmaglcsio
wmwfqwwqwsd
kstmhqbn
sfilrblubvvenxixuzluwmdrzhzwir
inyjnocihrpwupupkmzspgzfbo
nezpdbcdifwgzxve
oge
bmmfhmlwhxmtysqmcckgshqfnyyv
tewfp
dkrjiprnir
rguraqnjvqxjdxn
plktjzqpyvlcdv
bjd
pryrabzpcqce
rajumnkmnoeavpuw
xqluyrpaphwqlbbfh
jlgbrigkoqgthtuezwpvmeaqw
jmajdjetx
pqztt
uoqxnroxvwvvqggqnuip
pnskdhldswdhxrwjzbrfjztacwgs
ipsgoaamrjl
wgjppujgwsgbvnvuroj
koxkzpbhakmlhjtkupaslcfsmnwotu
vbqtt
uurapbxuvwaxqbadlpxusaepusjx
cmjaxaelcmsxkiryugevmnuqelynb
pqakor
nrppqkrxtddt
pgcwfxgzfdvslgrzsgorsysxtxjonv
mxknujivfiabssngzj
wozfg
exanqjhd
qokdpctzjdwbfa
onsidxfkxkxpsnvdb
unaynconavhofwiqwpaoofa
kvadd
zdo
qcppkdtsmrjycniaytfekwhbuy
jmwkea
pwnwia
mlflykntwk
kwehylsxizmypdygbdnquuhersk
advvzujtdngzavbvpseyxanrdsty
njfaiouagoglnbmijhbojbfa
eefjoskvrhogrwypr
pzbvxzcigrnwegcpyxo
vmrbap
zljskvunwsudpe
shfpqqirmzh
vczd
bqalmhvkclp
rxzsruemdpvsvcphczivreljargwyn
mlhnrjlmaqndbbffuk
mshylm
zmkjfiaxviiz
omhnfomupyhzzfetj
fhdsnpvh
dtdhgkeaksrvqteoimwpgolwlirs
mavzury
utibecpern
abjrcmaqzksmssxwpchgdxwbd
czkahb
nnkku
lntl
rqdqaholyuqvph
uohosonrlmbu
otplglunxxodemqmhqobzjkoq
ldezcnogchmetrqeyw
qk
kifmqorrhafcbfmgcpwb
duwzhgsinfhffxfmh
xaqujnmmdbiygdeed
naxkdrilgxhmkzxxvavxwzej
mtwxrqupdbrjkosighnqjso
aplukwnluicfnmkklslqxzjsu
fblrbzggvvjogsdarscd
npovfcqbjbkmdodpa
ndvnoyaeczoacnnht
xkxwidoowwgzbg
qtsytbabeimstysqtsrabmiog
zamykesxtavdxanbltpyezkcaji
varmvgxgsauscmfhugynzpd
doffjybsbcofiqapcglffcvfw
qnb
xdlzzsdjpbiztzyvz
kngtapbkwb
kdtrmuciq
jurmlstiackdoymjetbtz
zefsputyucbyfntfrwca
ioxjsfcdpcphvshalbvogvkmiayv
edau
egxoh
kvximlwktm
vcifqivsnpshjgwzztogrjnatdsgx
fpbyiipqhptwfa
rdwg
zsrdjceobxcdyupmdsucnnsjyjuol
geciwrql
cs
lvpawxhsphttlqxqmkugbtzhummu
dgljfgdzhux
bfwhwrlaazztfyrxxrpfbkin
liktnfkjhrxrhgfjiza
yjhmuczokcowrcubcobxioxvwqls
dxeaqzvzstqcedafjnfbsrqiw
trwgozborgjaerywvrjmu
qgcixwiur
rocxeaillecpsqp
gjodu
kifckwuelf
ybmjzpruxiklbsc
qugmsjkxdrtnmksngjoetsg
yvgv
qoxdlfivwrzcdfqrnswuasv
hyoglccua
hmzpccmgfvwfhbicmhailwma
jodfvorgqrnpuqjl
dkrjff
psice
javcfkcajidpk
ofraaawactabbnjstksbfm
ogyexxebtshi
wrttl
tbjludddynuxeik
vowtjzncaukqsejld
tlzckpvkbgiokhaxjkumzxbazesji
cbulqnivxmgcnugu
sziaqpzlft
hlebtqnpwphaetzgoghrrzlgxsorv
lrhkkzyftytvylbikmmfa
xdctrveyfbuezktqiawysueqi
cukcaybpeyxoeu
jrgjpfytjofejzhulp
aqgciptuz
hrx
pnbvmwjlvtvwacsdcmpl
clhavxxwyajarriyjbj
lbvntaqrxgmuvxmqhyfjntybvevpo
raptrjtpijypheth
unvvxkjxdstrfkvfcnuclhtxr
innixaomskxokgqvicjelx
xwkfrrqcnadimmlhqvpkopnonfcsqq
qrbkmadsmwfshtgc
hgolspxcbbyeamlimwsfhbvufrqeyg
mcbdkcqxniskhsgpdrr
qxo
aokgyjtxktrqkutmnybvqsjglu
mrklnollckewnihlbgzhmdyhqfs
atrnzgotomtjxturvfitd
utijjvyabkngdjndeitlgcq
ccemzcswgzpvbnkqijmcbsssrjcpw
rzzmiktsvmoxgiddgwwvqfhmvar
gycjmrjchowhnsgbyvk
mmprrqsdnehsdoa
txidaeunphivatmzggcshu
olsmvdkdfjpeicqtu
bahk
mlrlmuifctxrwv
vhblbvcqpswc
mewpsohofnnzaa
ikhofliokzn
nirmma
rjcjaerx
rysdxblqy
iudqgeqg
jwnudbyokbhtazedxazipwllbuaodq
uzemxeosamam
jopkys
vfdnszcalikftgncnr
zsbkyulumfbindjomsvass
kbmrojvckremunwvrxm
jg
ctkhcvmtjgzqwebgy
ykzziaxyqjeyajmfkmrfds
hcpjizkqnsrclbcxnabloilntzpsad
krjkvcgdjkrydoddrbb
hbxodfwglnvodln
sxyeaolwyfkgonsmiblpimnenw
cjufuq
eozhsklcteupgwkysf
tjblwcgnamfyh
lms
dnjjhexvjavexbryen
fnons
bqjoyivzsbesgikzlvxjnmp
vnngojaqrhrkprzyesvppkdllg
apjdu
mfepazhdxprorvcozmqsevhzigywx
qijnseov
kpimx
pjwguxgiwme
ygremrrkumndslhrgd
gjboifnlmnijbmphmiiaikmixaxhw
kdvhtpepwxphlitodxxrsqbwkcfhpq
djq
bz
qiwggrdvmmosmm
pxftebfqegbwqphpl
jkgk
zdkbwxgtynvdbkepaxwbnokv
ssgzfucsxfkavvtspel
fcxhzyhhvyjutpqqzxqfdbfgu
nxxmkqqvcncclnmnpukkdwzocz
bckhenhdy
aqvbxdjguhqbz
sjzbcapqpwuunxdknp
fizrrfjcfhdyhin
zgjtuzyiwhpr
cjbdtwuicmqrbbkkcejfiy
fdfzdr
ug
kndbpweimiomb
fr
hkdkstje
vwlkknxtzwtlxqcedpbhqwwkv
ny
akjbryubwn
czqwtfezlgvjdaegyezcan
dorifbo
gtlddfywdztvagowqcamszm
appldftnmrfqiupzjevhvw
vwvnvinishtyystx
wvzjfrdhynacabnasbs
ayrpveuegjohqlvl
ekltdekvdnzb
qtoubgtbjhlvgevahlgiosjljv
eflxcojegtvhfqtrgiijdujbczkx
wylrakhjfgxkfvtihztsraakyetct
fwhppxzmnbnqbslqxyoppsiewuzmoi
cpsrvwffygknxnzfshgtpuc
odpyvxkhb
icxouzovxoeowxbetpbtoxel
fmulhjzjxibxrlrun
vtllhixfuu
uelpllzxumfmhphe
vptfzcuubsnnwasoicb
qdeesswsnxiolyswihjgzzqlgmbux
pqzxpcwbwmzcpnpjkcuxnvfnt
zc
afqexugvl
wlbauxlpanmekmbmluyptcqp
exijugswjocvsxqbopcaz
jbjkiarmcef
qf
osry
ebqb
vttheuoql
lndkiqwrwtzyijbplywceajletd
lkjqdjfwg
afumtuaayvbwede
pwqoxwkkd
fwhyjfw
rh
kwtcbsdb
hlrihftyhcjulayqypogqlaeovni
szyenysiidzuvuwo
xxbkqudhmugxhbzmgtr
oysvddvwrzubwckk
kdjpvtujevrdeiuxzu
im
lgdxggosfkvmukghx
ssk
gkxlpymjgfiscvihsldygs
fypgjawnwxsjnmavpp
pjkbkciyfcjtdqdeegneoztxb
oafvxigybiazlxyhszt
xynczp
kenqljlqumzppgcymghmoppcuo
tjfcadhvgqorhxbekvtnofoseo
azwal
vmnhyctmbv
itwzlxxbicrausclbj
lbmldnnvhr
mquttucowodghmhcqakhsouvklxtd
ipxhgvmmsxydwndgxibqr
fzwbiefh
dysjgbtpidumihsteulmksi
eicjtzqufxptsvwavqgacqgp
ildbsgom
esbfnptwvtkl
eggnhirpocsfcucrbzb
inwnjwcsvwvbhwlcgwpgvcdvjyvyo
tay
wmcvkkznriyzkkqe
gbyrhelkrcmhg
felhnxqtmeipachm
qpaleufwezsrskt
bchprghyzywtqkg
iuiqhfscptmblqjnkldcwixuuv
yagzecnvqkg
bsermnzrk
vcdtwksvshmcgyqrndpo
xsknvjyebijjpqpmvxdwachli
ummdozrachufdfkzmrbgdjcc
rwgduqcvafbtgqpeerypdw
jdbnug
fgwgoxyrjq
fxeffdtwygqwkeihhbtyobfev
xxrgszydjxvcdqfbfaiteuxzyhj
yqem
kxcfgwmnhkxziibztbhe
sjhkdgmylqchihyrzgid
atqfyiwzqttszevudiz
irfqldzz
cucfvktcurwpyvnbmckatbyhzzqann
xrrwnjmpagazpr
cfjikzkmxmusvnwwtilwatnpctrns
gzcpxzjveqjnmqjgwxbshqbofkw
mqptftfgiznchpxnt
ctqusassrwrexmpwyljnqebwztahyj
lgsqgymuslalbysdzacprhgqzl
fxpazpbqvoc
dhsrshmlolyhrwsqhevowdneiy
vnicuylensdgiuqoohpprel
dcqnfgxadkq
be
hidhbfmiqqfyrxn
hmkamlcpnilyspfcxhqleq
dvuvbkfocnnhnopah
vrorqjiollgetnavomlgwwuqbcx
krwshvrjjkktkxfjrk
nsqdnfcwqrlxswrvgpgeiybo
chdmqjvaxmxszqmpbllgjfkbmlypct
edjmxfspdbkbrevylsxwtfdea
nqpotlfsnmopypgqcjaq
jbdfchqjrps
kowgujpjvbxzubzjprjuymocyvpus
lwbyihprjxdiiltlbocik
gedceilgnfumojqa
ytnkxpbgclafeeunnie
gknwpipwzsqqfkysigjjttmoqv
jmeq
dmtlykpmbb
fmoqgqbhitj
zjzzuo
gprqgvzxzjylslzftlmd
qj
rtzgqsnrcfsh
nakhzkwljuhtoprcajedghcfqun
rqwjjhdj
hfqyuflh
qmyrslzgnn
cixbpgnijxocubfissgv
dbuyxbgfsgetsysqbxjuqqazjjfsl
ajdmdcitrjhjlbjbtuaegi
dduebcraqyfbblktlrdbbl
gupllduuizgpgdx
rktcxlgtfaagszk
mqiin
jqjklpbfarlliljsdvnotrclurpz
fyeebkigesdloaheuwkdrsyeqgw
zxw
gmlisognahhekjfxvywvielvtt
adsajuvqvawhsgvqagonejhjluls
xeqqtcqd
lgaghulqctfqrpjnvbgb
opsrhoyeq
puyumcitokeoobafovvy
jeqmnbyttoenyb
hsyisy
nol
nwbiutozcebko
iookcxmlxjrbf
bszvwvqxuovhcpvlokgypckdzhk
fbrddipnhvammscyuapwugierzn
rzzrir
zzbzdijmnuvfebk
wlrkcseohyttxhfumhq
iqxnkuwdzpjezdcoohtcvkuyv
itz
wffeeewazcjytzjvhe
gqzgfbexgrfr
dpnyde
adlgzbtlucvzkgo
tbdbpoidanhbheu
mgrhfgesntuyweskhhetyohzy
phrksdkarcqfr
mx
heejjbsec
ytnefdwcsnyddh
jjidgiybinlowvycjfukyygnae
azlnwyegm
pfdomq
mwovih
slfgcxhqlgipricrljen
ulqcsrwluqkqcpukdhaa
zgcgnguokgqdu
lrmjqcqtkvhhpsonowakyzswluai
dlfltlblkovwfgi
abmrvocrmyvfiygwpeltrwdt
qrcbmhaojig
prmavb
stwpwcuglnpaxfrjqjhkjrdp
xaiwlutrfrfzoruh
wcqgssfw
zmeizqqrixvtest
eerimlampuqdsuuoitgxthjnksv
zobvionrxflrita
euzvapxqllrkgzvimzxqgpmd
ygqvzji
bz
rgqqylyd
lwua
wvixbppjrcvkfwrfqspizxcoiwkor
ytxlabay
qxirwd
dtxsmtrdjppjyieqhsl
cjzclkdveebhr
klkcgoytuzkwbtmgqgkhcb
rxratmslr
yqhpdzjfzd
uqqxyiefhwlz
zwhxpcrzyinpoenjlenoefzbt
azknsymvycarcbvqwyunxhl
loctibypeocgjggojfbuwawot
hj
vycdtgrqsmcrbrvttwbkap
ngyvhvxqzg
fkicqojdidlkacvrzpfyfh
qusanmwakihziwvxoqyqwmzfzhkkk
jdgxfczzgn
zwtap
cnnyuvyfebwbkhjbmxxdscjheqjsx
zvycckxxnadthkblffocpqabapprft
fjc
upyufyjxomhrbyosjqnzlmyxeyq
twkrrxbjsrcycvqvnly
snodbvxjndohv
jbezchvljmjt
jetzdrwgdjz
wmepxifhfdevdjefrnbdpeyksqp
ljacwrmopfoxarnwoepbltq
zgnwmmtihlsyifvgtqtod
bmdpghmlvxhqvem
ecpoiiyaaiybwrvwxd
cujxllr
aphxckbyhvljsz
ctslnimorlkfbngphho
fqztsjajsncszkwxfomlicak
dydp
jupdrzlckibdvlvhphufz
ehnjnmvwukgqjiabbbulnrtofisqr
hkwzch
ibfwxmxijeihvoo
jvzewgvaovclzndisjzxsdeiorfg
wfzjykkfyrwxdklpnqtgkpfmtbozsj
dktq
auzyurrllkom
awyqipwlckahnrfgvmpatbehrhpk
ebcvkfttjwwdpeuhhvv
fzrzuaqdafxqwiensawoxolygo
twsmqpchxpuwneioeuymdm
unhlrycn
brnxkdmbspurco
dwmvqxsgrtvitxllj
rngtijiefzlztygpeaclhtfd
psprgfaopcwtxrsfqtmarqomc
lusjzwgvxfx
pdjtasuwbmfeq
zppbzhtupyeqe
fbisavhfciklitrmmazeu
tm
nxfaeewxuxdhzhtjuklsvyix
upxtprnynuaojmuewxm
cekstmporeouphcjiws
uehbewnkitmcy
eqeeaphplt
cqmbytmkanwsmkquegylnkuevwxic
gsgyunrvb
tdhzvufhgcqoqzvmoizyevcvn
vmnoqltrdesvnxfyr
ipyroepwytimbdrdmyx
gicxjfzpqctsfoz
wzpksllqjyiyxaquvxbswzgclk
wruucflfyqvitzyzwompwetgd
edskskyxbryntdkzo
jmmigbfxerisfwzwropzxv
dyj
dmjgxwbuisixuqsmhv
jfsdunyulovxszozsuhdoisykwha
beljpcjnbidwiej
ihpjalczkejyreaygautktqoh
zkujheuhkitqsnggnqvo
cpfemiavljvvfsgrmrgvkfx
yjiamfbajifvnlmwhvxnco
zflbfreheohquoehmehklgtijpqekm
oywqmgecvv
thddjpasasumoy
tagxlzsazzwnzzelrp
klvxwmvchyrv
supbdycwkufqqftc
mafws
hlpztnbtbgruqukiroksqscniuqd
mobbxnqfqrhlmfvjbxgbcsxbfcoeh
webaxlcfqsfw
rsxhmxneutngvkgeogmbw
cdryfjtleqzhsxyhi
uuqriyeartlufhmrbutssb
bznyd
hrlkwexwhxrudfdjefikc
nqovsytdjshkupnklycxpxb
zm
zmtdrfdvcedutdjhu
qslxhtkxnrjdxjfyzkedncvbg
thlycnbuhszdtcxqhjyfjtrbc
thlttfpdjfwksigtyhiopgiry
qiwvs
zkcxrrbmqixmuon
paqtpvptus
vbowrpena
xujixuzudptoosuaojdj
miqjwg
yajiqeszalxloaltijpzzhytoij
ueputmp
itczvgkjdmnfcdalyuvtnjxuo
> \w:
vas1
fO6_qxYf3
kz
V6d
mTCAyLfoef
9R9RJtgmED0hmT_J9hA
G6xR
GTnsng
kMGtkt46jUEJNkMjQ0_dfw
i9rqKJhwnINY
4q45i1Vw7lVk9ydN59eq1voMznEB_
9XY4so
dLWJE5kW2St_b06KiUS6VtseKm
7otxAjzH1etoXjQsRPV
_oc9_Ui3y
mlfr
ZA5QW9
IX0MH21b2
sOT4ozUweHmjsl8SUWarlv
ADnDWj3X
MtYZBY49OTSKl624d1tIEPyG
7qdtl_gIAfu8
Qt9
ZVtzQmGiAtYQU
5461QipEbbrtGYaDTlrA5hEb
n0POoWUIFGIDs2UeGwe6ZmPUNiT9q
bwb9X9U0bBzHdJe
2_r0asE
NbJkpMvlBViAs4YYS0NLz0uZ
vqlzkmjNPRU4VrQiCkU_wK1pTqQwc
Sws1jYgsNgs
P4m9r
YSvGRM3UjFGGB9OPax
zjxt0FwtB
ApCfo0mpz9N8jZrM3x2njoh41rf
gXWNn19eNE0ZHHSeJxwtvVCWkB
phS7XRDS4PHsN0hWgDuNo
clEa7HMiHw2TqUgswIwqDmd1k2eXA
vl0Yi9D8Dq8MyruVAM9LmV
fH_
Otu9
l_MVEoEO
DHK
BQ1jzj7
SlpfLkBlN
eTJ_vfeMHqrjDdA3FFMe7n
0s0Wl0lqDR4
83bepaucxHmXhS2oD24
3eUR8Z3IE
73DFg_tau9plAQ5tzU
tE
AKNd0Cmd
jf_4QxkGw3I5TIs
p_v5WEUQzQ7unrKR3_VMEq7g8KHEc1
oekWq6o36pfYDWI2T8BddQsL5jcH
a7e3FS4qn0_Y0GacIJZhqR1mjz
p8T
B1KnE
bXf8etS8Byt
4Df1s5FITKVFdJol4UA
qU40eNH
ow
D1vQLzXihfOtqM0MjOv_XpUA96dINz
DdtTj
ItXV3pZGFMq_WUlXaW
tYGGD
GxOso9IexMnVCbP
Fr5eY4IrMqNuIdN1BAlPsX3Y
aNI0rSd0gtj5
vGHiYwXobEJwnH7hbH5ujjTsLnoNs
4Fi_ELT2OtlK
Nx8IgtU0yUKb4YuA
Lximokd
IE6Zn75UKo1W8b8iy89NKD5
k3xwfGA
zThEnELs1KZZc2sTEGRf30LxF0NS
2Slubzsv_Bdhyl4lWAUuMT7_NqubV
oGKPNipX6sAeQ6KpgTbfO3S
TzJqXDkCwY4EX0IBokMbUW1
VFade6YSyNweVLL6DmF9hU
lwFwlAR7jEPwBn0Wm4NGb
zjG7PH
wWEwz0MNHbmnNL
mcXX1Z3Xzs98Enh7z9oxCjNvJLd6
cVOGeA6bAFzkRA35wcTomdkJBKtv
2RPIBARWOHCDyOIhGk6KqQY
JU7
HXpziSuR4yQV1I
fI1uuTu36m0PecmIv
W2k
trjHFt5Gkk
m3Hdgwz_mm
ikbV_SfqogiNmw6G6mt
nLP4s1s_
Yarm_p986buEcE0DqKhN
0NU_TmnHmbqQ3O054
X3CGbW5Ob2
3icoWsBZDQ
RMgSeo
KKPKDFHzMUMXPcPkN
7FC2Ppw8J3
wNcXp8bn
Z7U
hI9N_sHr7YzBL7fzowKMS2aP0IS
zLIsPkNjVo6
Kj4nAArn1uiBoiZ5
8IpN9Q0ZBsdhb6ax
TWm37BTDZqfQ2MdjaUr8dUy
AyUr
GjY5yfH
i5MmLXh_m1pgrDu1AjHpiqv9b5
ArSKg4U_TZT
PYF7z9cjnd0J_K5wU
CaYYg_cK2Z
eNaGy2ou2Oe_s0cp1CJqNx9
bRNdplY0MYLKBGqe8y
A49xSutlzGYZ
qcn5AkdFzLEkSFPd
kgADd_2u_NeWDCV
JPXPl
ItO
t8eVFImeDSoQPBgELiRF7n
jhJSl4W_vnI3qeqt_O6BGfztq
BUWMcF2hs4RPD998IDFYvexF6W_OAv
gv6r5DGRHbY6g0s3J
03S1w5RZYqVH
hpmxbr2Acau125FtkSvCFe_0J
QwnwYiMMdBBgcXFWt_CFQU3fIl5LmJ
rrCO4rWuV
4zRoe_dJDLn73RBi7S
89P6iRkhWf9PwZCZ3l42pxmM
3X
2RruOvTJ_SBQXJ
piuqAQKRLqJYPnCuC0vpSaB
nO5qxrXvNbkf3He
jXbg_uVb1O4dWT46cxu8
GQrTWi
E4v5eRNvbQLCBNGvOHJAuE
E_TDjJkwvv45Y1zIDsO2wITZB
HURdJtej7arctrU
0_rCQ2dC1sOWlfFNbtxQ
wBRQYjseQNuCWYeR2nLsyH19XbIC
6NK2GqIutHFtu8WEy2r
fs8Ur9m5Yo9Ql5Jh14
NtKrm
fZgpeA3wHfo5Oty
JmE
Zzy9b_7s3oB6Huv4XLzPxNG
4Me0F_
4EkLsKicb1k6XUrZWX86
sKMIgEftkrtAccoGioP
BUlkowaA
CE
mdVH
yWxyksiKJPoiJCN0SYGtXAFHHtPw1
QxyU3
dv4u8lWIOh
jRM7b6zZI
XoyIqTu64l3nun2
e1pIfbpqMizXJ5QttQ
jdWr91TgMAnDRJnGMj28JXZeYIUbj
6bNzF_fLj
V1murPxiAaCBS0_Wuwpa
wNr3vi3kCKr2FQKpVc6E
SpMz
6hKeouJVOlmq5WbOl6PCW_tkNcK4
cTM7ui6wskChgGF5L3fM
BgfIOtfhHgRDWQaq5nxEltwF6x5
JXPGCQ1tbgL1VTxM1OrOuQlAzWmf
jICcLVdia_0q9oRMGWcZoVJo
WnaB
VeqNbso
GVdEr4re0NDMaPncCagzWi
oZuII_MAmc_BYno0jeVPg7bNBivN
rLYv
GN0CitLTmEM01yPz_nIEL4
WH1LG2Pd1WG_9_OzOEnxk
zjL209GqWqoZODd92k4H
etQyLgzhbqQfijVosUQU9crdJ
TgRrXypXm9oI
XpvCzZG9_Kjt
W_6qfgcvLNhc_1tlgzis8bBLVMh1XU
yVpJecRwZswlG7fTjXCE2sy3
ZRDxshF670c_khX9y7Ch3COvVI1Hqy
1K9QZaD6jxeOCd8GvEjKVynzV6
9aT_XT3UArrFewRL6OOUlqq62IVaGc
lKPmJmI
jvgs
ROsmKG3PHUtEC1DKNWK5fJ7j7
AGaHwiTR7s
u5v0bJUJ88M_TecrX48EXVwnJS
xG0m4BuoXvwjDd9w5txLjWYO3vU0
lf7E2
e0O48d
e3L7jrG8oGF
q3TfC9_R3vGIoPIPBnuUw
kcmDRTGO2
aUTphzzEh
0D9KronTePdX
eyfr
oCltasCFGQyX50MS9LdBu
UgVcOfNQxY68UV2gCYDk
eYlc
ew
FVqNnRKXkOA9Ejv1I_6Rg3
anLlhVse_ZvWrNUJYBcjOBG
23jlvLcS1CbAXUCT7LzJMLFlHY
JNAED6wUS4
yTre7qO7bjONzXusCgK7Wb7
4K7EyDO4E
uQ9iYTnPe9oTvIEguI10yQB
uow
Gt070GC7O576So56CCLbrBw6o9
alxIRdA2KnN7uly
u4Ei2wplWejlIpcV4yRUWow8ceFn
H_PO
oQAwP9T1RLdpAvh
_m8AvXSRt7uu
Zr9iApgvcqYruf1
C44ihwyIIZ8cJi0vqlcn34
mVNrcWgzUkehEs
fMLmJL8xPopEpeN9uUsADs
_MrIVbL16wkTnug5eCClSFjaO
tzzIWkyQjZ87rQLq5Uzfb
UzhknjFmNFaINLveqzr7R1TWY39x7
UyK
WuxBk1KaAWQvKADN3t
4wmRilg3sk2Ru5_SGOdwjBZYbFfis
wqW0pHHBI3pMMf_gCOt
GprB
6W3Xstgiar1lAqUfpYFbk
VLZENSDQmFhcG9N69FGFzYk
gp7SuIfj1K1lFUUDfJj5IAPP
nrPz4m2IUNa
EFHJjAeri8CUWB
OudxiuhVebMLJEaYQ2ACDKUlY
wUH7bXyKlR
63xRjxk
6WKK4KVVkCnW9nGdQIQ
5Go3r5ctVZo
eL6LugJ7l8IECcJzmD2ArJh8nlNM
GihRW6ODS2RTtZo9vYDHd_
6CqyZjIWVeJCjWXSc8qgVtoLOQPbW
j42laASn5LHOi4ODn_WwfgdslL
GH2PUb4bCLnmatGBqy
_Fb3ZyQuHn7SPw5
uIMBTfWnsm0abTUTN9FDZol
EOFFZu
rZ30sASJm
S8H1AyG9f6NEE_Gu
6jSZ
WRHslssTvha2s2
DMjrwyGOujQ
XvS3QjEL
tTJq8qCDglsco
Q_9VbBFAnl5CgoJtnsKCK
74AYGfjj5GABZpXx2I
bE
MOXSAq
zQApt1NwTps7uLlIPz7gxnmDzBI
Zcq
S8HVlc2spWl
4dn
2rm5f
W_V
g9AMwrHpYmxDyjdClyMmQbQZDCwe9
FqoElJ
BScS2tmhIRvbS7YbBb7qh
rfJ2ILQaj1WC2bBIpKxS_r089qN2
bVxexlhuZ9SiwG3Ysw
_IWYFPNj6G7PcBb
O1wWzuFs
_UCDCedGU0m3AG_
CRf5_1GYV4V
wsyXcuf1Z3GVfBx7
DCAbIakh0A7up51taExr5gQQ62raaE
uvAL_1NkEDCLq6b8
hncGBmg1Pt4XTO8Q
TQhscqB6UkWSYpX_SpjFirOp_OW7
6AimhXgH
hsbzCnvZanc8z
ytSIZS
9lvwWwNxUxHOAT8TvO717M
J3N_oiKZWnpCeC_ec3zX9g2Ig1IV
KVMZDe3hSfD1GrC
kBQt9aO_9aCg7QYhslCoFQvGH
LF5F1B7XD7i75eQ8G5e0
68U4r0pWlINgjUPHRi
bTNEx9YKxRIIfJ_4WuhtYwmh5
2zQV5XLGJJMp_xrPIZsfELy919XBa9
7FwkirZolthvZ7hoX2jJMu55l
Jhge5VS
A9Q
EPXgB0qI
Ly92mmL_Nm
kbt9PhFQ6c_WW6VpUd
YQah_I
J7VtBR89R3Jr6G1gbHiVkS
Vjez1bZZzco8KaEKPY9ij
e4acPm4ejvqe6L6_rpEokdyvZhU
93khgZ9Swv7cxXtXBs2jySKgpq
pEk3slpghDy
Ls_tJvtDlaT
VJP6SLNzuCNSTA2t
ZPt1b3QVyuVSTskbfaWm
jjQoE
ZLX8F
clqg4w9kRRnkQ3BC2CNZ1K2CozHqeK
wBAwu6EPY7PqSJz595Vf6mGCTGO
HxKjWrAeJv5
MXLS
QvOkMbBKjyFAmj
n6foQTaBVy3HnJe3Du_LJa
HwPXZgUgIsE2
NSEvN4k9T6SunXrFZc_
nlL_bfDKC1iRuOWGFo0Y7Uryhm1
wL
VYgVtRMl3u
FBvjB3mMaZeiC1ZCaGcSiui1cg
HSYDnKxLdHYFJOUVJY94nMniaG
61LNsDPkXKw1N
Jq7wux1bsD6iJ
9j2fdrmsRMJo_j8qNQQioB8Y
QBTYX6ukcDtnrRj
h2Oz_j4WNIbE5bWNCwgkb2Iv41NchB
vSe1de6eSgBkknlcYB_ayr_GuCL4
ebsWvqy4FI9vyY04QGeEwhl7vzu
_5c6pgLqnPRoC3YUGf2_y1JAUL
meikNST7ekJZJL
QhtbIBpfU377xSfx7FNzI
UG
hsQfNke
qImeR1FJgDXp05YT6Ki3kGRoVi
tDjBCRVm9pKgXyCHcDUKV
Eukz6
cUIpDX6ZS8ASLika4meU
mXdH7HU_xLxDbFJ7kD1u
3FYW
LNwgmy86sX5DATNj0f8
iGWqVstfydnAJtlycrGct93LDdzKXD
EmEU8_Iax9iYXKPT
CGNWe6voSJpDBsJJ8umM1k2hwjWxfQ
VPchW3eQeMY0
HOi8vLPTIADJ
sulVjWQHtWgv
FbhtBopl01SqxNvtvqhZUTdg4JC7mx
DPaMmSMGNdO2w52g5b2NW
Fy2KOZ0s4Y_xq6NhoocL2qdQ5bv
Dd4UNBjqySa3LJKe
F1Ov0t4KvaOYMBH
lAz_jT5ky5
a2cwGAmofQLOdemhg4bvie2dt
iAy0Hu58ZQeWKvg96nWZ9U5
ay
k1s1E4hpa72jFagQX
y1zVpThOrf79wJQ4RcB0V9zJie2gX
vtqlpKnl9m7GyLiWshJSb8G2
aJfmZ
sqLQ0xSdJdOvMnNpSjj
sHtNMBId91Tz95lMaE4U6wH_64
hhqPBGxD5IEkrjs3DxOsQ
DpiDU5F8oEYibwCnDd8d2s6XL
NTF5Fa59ET
8EhJzx
eHhTuezdY3BNEmZ
5yMuzP1bGgGJ7r1Omqowk
upYlClytiyAJzJCJp5_G
rU1yEPO9ReJbWKb
KDHZltG83i52
Q0B
o6gD
lT_sdj3wczXzfeL9
0IOUX3oD
sJlMvK_AwdOp1pXhy
b0ufDI41qs
YArOv6EdhkwaBbOAP
iKuB3NYt
Lh7aIh39Zphon8StkpbhSCp8ss
XO07eSzTcEPuOdckv3Iu97zQJ0_V
bkjklVDSgiXHs2yd
zZ8eE_8ZFsIh6flYL42L1
7Lvzl2Iq_nsZDE
s5i
W49d9m2c5pcB2HBNDh2w
1mlZ2cxBuoLYhlUKYInwGZQZK
B22onzBNO2aG8pyAux
gCuISdhndYwRs9UNNkjgs4lEgNM
ZGfqp3WIF7SLK7q_G
MHP4b7yXTQcNdi7ZYnK
hWUH5qi
9GF6izg
KGrPVjeLWQb7pMx_9nxUhULE
Iwc_vZSkICH
ugDSqvwSNX
MtZBDmUHOm00v2ShakNBZLQSdNbfX
2IEfppCg7PydZwq3zoUce
sKHS_ue4AMyTvGUcJmASratg8p
mSmeu92dERFVQNQg_GWEMvmv1i
dA3
XCY
JtD36GEYiqTBVXWHW4w6Px
QK7DWglg29bnvA1K_kttSLzBp9JS
NAMF4
fH6
aFpPLQeAPLZPLxOadCDbBWf
uiOww3YIfQ5Iri_LjnT3Khyop
BV
9FRnp_nWRDzF
NRt3z5x97lC
q6lROsgz
pOxWrP2WRq0GrsRgkvMlDe
LAr6h
dzEtgBGmE
kc1V_DAQ1AFPm1Dlw5vRTn6HPj
SThIQvGVcKpLM
R_rKsA1oJjDUDvTn2YO6BZ4
MxIbJuyZv8mWRpMS
zVpWG_7h7hjCz8RH
yBGZZlnwxEdBfuNboLbx25MiEbk9K
DPgZXWYNGXMolRH5p4pOQ
cOQJbua7CpcYJFfvZ0s
8DzPemMb_crt_gQsxqOI8OUtLe_
M40PmO2kanya_uWuZpJNie0QBJ
ixjUVyHNx56Xh7gQ9qe
w9LrmMyyNfF3cLNrmhGjGT9u
7Zq623WUonluQ83MQr0vy0B2x5o
lfAvMd
xcth4EWyjSk1
6oN57
sFpH
GTSqDfrLFVSi
78qbXVKoDBvq6yRQ0fJ
ulOK92rL3f63acHR3FpzNJb1V
VL7rmV_
rrnaRUrIOZ0Vpe4N278wuRz2uKiWnb
AmGTwi7rKxK
W5TN83d0A3WaLRzxmyFa68E9s
EclRIF5x
KdyxqgsB1pM
pMbS5BCT1CEnlzt
xbnmoNRKh5y
YYmKpp9s8T83
dkvuVU1VtmeGGVbrOSs4Wy7_kGSc
SX7QU8Ck
pXEehg1p2iKA__G
Pp0z_WtDhPGs
g86s
z5jKX8hFQHnHHGUIoEam27Q7
ZlS
LVfyoI4tlGyh
bGNLBPaG2e
llTYG5hwA
IOGMNweQeeLlrtQoGTg_FuqA
iV
VHSv
XaOcddJ8ryl8F57yX0SF0M_
NzDy3
44TmhJTvlx
0D_1DBaWDaPq14U
hQo
1S834P0yKmrB2O
GHFsq3ZFNMv4Y4Mwi
ZfHLAHJa2em50Cjw5g3OzA
s1fi2GRGlyC5jZUyU9vwjthdptkhrU
j2gF7je6kLnV17
VptJTvG_fzOmfl_GG6DbjIPbczw0
QHtcyWbO71bW6Jj
QQEa340JCwfWH
7p63gT7XmIxSECXq2gA_YU629dm
SkwZH8xQO4o1FegC
mxD4GWfdvZHGJiGYj5Sr35LDjR73k
yl0wge
1aTGb0uycMBtqZWEXYYNyMbAOhvV0
_m
jl4RaYe28SK6iT0Y
231mnRCHqIKURLsMdj5aP6
KCkqD1M37XlK
JVvXgux0rsmXmNcr
_fP
oLd3OBPoZ
12CshE6vS6eEPVsCs8BV2y3
2ghv9MPMf
ZdPIWJcRplxammyKDz0Q8DL
xK1
XjFHI
2VUDdQoPMvqqBuU9SQf3E8sy_CuvAz
olJHPgkg8g8EL5Zgq6TFi
8mumZDXOkFdo0fD0a2
dNKTLc
Ndd
sawJS3n
30zNIidK6E5RFPqisZf
9Wc51GPb0Y_QqE
xINwwHdh6
EK2drSRI8xiZkzu
kjKc6Ps1_DItH2a0fCPZCCM6b
tHzaIi3B0gcXaR8
IZ0v
zuFVZ
ZN0iT9t9sjMf7ClXC
yFV
u6w64a
Gi5Xvk2
38wdDvbHWkHUFIwHX9TEVImzyEvD
3QSqfkx_a91Ney_XjNF6lddgO
uKaEigc2fco619bPdOo_Pbpgyg3y
McAWZEquAVn9l6
N7iUmQmEnCOMp5kYriy6g0IEwNq
Z6AgAF4R
t1b5Zja3CP
_BE2u5ry5y3kjqC
qbGZjWnyXIWyjctKtatMZ
5uaJjsCjL
jQPLIQCd
CFW3e8T7zk1
AXEdt0tVjS
NrLmLtPyGydh3BrMqXB
FoDVxD
9LR
HlJoDzMSHsxmXy5Dzw5IK0ohCOGGK
V5XylKYCY8fWTbmUfAv2C
5_JbA58v7amrzomfP3X
NQM0
vCL5p
_FJ8z3LtFhNJNa2oz_f9
kyP8naWsu0n3PrKwP2q7Q
ATFOo9tzd3gE3f0IXPOw1QmM
dgjQPN8pbTRYdGfk9zQWVBNll
nWj8
3dGdWd745NNLcTDn5dsAUlrc07jo
0xTIeps_d0ZGDpTneDk6u3TImxew
Kih
a4GIhejBBSc1mQYFn1mYLZoUeE4
HKiogQ42TIn
yz
wjoosW
6FB79rRBuWDXzt
QExdN
iVfjgQNjiihke_
H26aEkc0Y4A4da25gN3FHmcnD9O
c1z3Dbp0clbIhSHDATwfIHIGgUExW
ciSB6ddz9jq6__DcaEHGYl4ihz
5BdCaDqXTMs_rHdDhiKGd5TBswD
K7I8PesDe8SZpASQKoky33UGtsqlqT
ecT2IA9EMB
E4oKzBarBhfHyrX5_DqjBTtpG7GiS
Qr2A1xcpQvEe
WR4nRmIJmsC
7ET
5PNqsJlmcDuQt8J
q2B7z3LM8WGI3A
lxTDsrWtyouxpLFrK6er6
kAm3c
RPqcVULiDaQUDLMM7
QA0GFKFeBUQf1q8JnMAh
mfX0B
YsCtgIZRTEri1TN
BReJUBahnXGtHbor
06M6qHQNXp7zKP52PUoQj03
5OFn_xDwX39ykM8U
wwi1Pe3IJD
pDibXDRLflv2V8aroq_JjZ9fa6XMPd
6o2AKKPvfN_VPmdP
zhI3pY5
p8z8V2ChCH
2_1FedTpO3vPaerA
_o
XZNrRfzfoEa77qwe
XUPztARNAjLu8yW7TQ3V8ZkOW4p
_Eryd4Jyg2X1Wdvp
oOEM4GPN9o96n8Z7zUmPMw12
2fvWi
Dt2l7xFl2AkqiUR
VUdYYVeYAMR8KjZGSJxlbznSF1bXiP
qph3fHpGv
KcCMEaqJQPLIZ2yao
Y1lrzWYPUUVVfWNwBcNpTEpmupF3VN
Urwe_of53i2YNQ0n1hCGCfi0LPO
PBvoO5gGq1ygxwQ51wyo6u
m50MNc
bYjHyW
hyg_mUT7JR
kPzX_0ZkEjzbxz
NO5OB6zacglUy
HPt6
RaDv
qD
ZPIWZvusDpgNszze
soN0vXijfCOiZOJ8JLmD
rnEGtMtZ5MMPKWmU91rovzSB59rS
lsdbU3k7Ux9_rH9beC5CkoblgvbjZ0
KCzWJiCP_1PQaw
GJsaK01nK9JtuT4YT_a5Biov
riwW
eYJwbVsdNDdVTl6hA87A3JFkUG
srWB2NBXSNX_2DFgPaIJsZxM7
5GjpZ
RO4HL
fGOb8lj
aNIWP9kZ3SwZigRu05qXhsl61lrk
k2B4A1FohSO
XvYEaEeu2O3q6yWhzYuLVb9li5g6Xq
I5s0Bjw4KUICVQqBDE
jeflG2lF1rXI
QgDLpYtVeNFlr0
q1FGC999NP50EmuTXL
SLEUVMqPD6xhS1eVx2xukx2WX
ZcmIV6DrZLFsRfPVLbB_VZPd6eY
0OOcfrKVSHObX7dPfYzrQHmor8ycT
YVZr9D
_oSBFBt14Xh29jbg4h
Dmk4XsOky3h6hXf4s1gQ
qpxPEBa4PQxn
yKQjL08SQXJUeWIM47iluU
iqxOS
oQY_nQ68Lr5VvEsM7zRMspFWE70ju
XSmLujCoyZ3Vykd63_ANwI
gxwV8SP_9Z5ciS
q5K24Z0uRgUOr
CbVRZzSGUVQvWhH0mY3HUXhlWk
jtromwnID
jbfVEbcvxge7Ei
MNOc4Ri17fUTWNkperO42EHWl1a
pt0PZP2qsPBzmO8qd8s
Ftfba
aw9iXYK3X56AbycZmhs5y7JCmWvs
vmkzC3hAMYHOVwm_ZOlOpw8
kyQ
D1l7_05GUfPPIk3zJbD7JZe1LQ1Xr
3WQXPWV
ghgNUhxKp6A3dABnh7D
jLMKRtIDJ52KkbtiHIIDM4i
kjOy1M
ILyyhC5F
Xl1VlyViZVOdI3wJfkXXD
Ad4tWheWU
M_vhNit5AtLXy8W3E5ohOD8myt5
VUvjQooFjqIr0aKKhvfwiGVvWV
2Hdr4hBMYUhJ1pPAEVYFl
edHzejVAPKPyLOv5T
Go_MCtFzkRqtUzwMQ_h
Ewsm
_TQ5zTqrpojCyYDgaXljHoBU89
Ph9P4DSgCWljkE8gjxSG3
XVQqGo_rv4T
XLaVDlASYKKLgOk0OSZFD4nEElK
mD9lc
XXraMEKF5b_OaoODavyZzZqDP
1URb
K4YiFGu2fM8CqT1p5v3
CVai1gTon
Egmlng5RtS7SJJ8jdw0t
geAwMipHwieJAgtBb
srMAz7vMc8lVzfHBFZotEdgIFvHHxt
I438UKyYu1U684W3ehRZUlYP6
8sJBysfuTrD8ej0_1CtJm4NYUBit
B79oS3p6F9rFLaZHhPJSOiYHKq5XZ
3ZTvOH92oeMjgluB3D
32zaQt3E1LA
A3lvRAmoKLWs
LxsuTEe6FM8OmZde2hVh2E_s1w
x8zugzfT0uHumOvExiJ
eiUW3
aNQ0yGlJZ7hPKaFY
Fn8VL03u
zOKuNAVEbQVQ3hIHCjqVDu988qel1
SnHqVi04QnJ9GfEEDVwEInS_
pZDAI1eeB697D4X4W4T44
4OCBkws3mSBT91rMfosKC4yajs
65Rf_97LGp
hPWOcGOhtZxsGJ
5KkA0eFMot
cw4gk3FE_uu_zbzh2PTDeYh53iO32
Ooj
EWaS1y7er2qOHzBEM1G8f
SMkCo8Ba
6h4gK5qc4Pz2dbR0m
z6bhCo4dzkDg01bGCbJ9kPg9mFa
hVGIEWQYb4WOGf3
ysl3b5i53CrLmBJx
cd78bBzwu_mVtOoL
TgLNbZi5HUsYCcwVg11liB9KA_Y
mydnjAryVwAOFiOefCXrH1nutRfDM
yv5L0oHwMOS7kkzMYxo3
duIac2F_n07rM
vpo167KC01hMdPfm8
0BAfIoMKcWeor_D3k17YmP_H0nuB
oJXE3y9suV2gWiIxy
nE
wwqz5zjmZmjpji
wQBWwqI1cDPx_4Qlau
SP9MmwKdpaBrK4
YA
vbDTpBJzt7r
lit
7zaMF3BWX
ISsqcD6QC6A8
tOGODgo9r5qA3spw8cDoudBJNhabq8
I561WOQo00H6VRswwqhcSlN3HAMF
PAiYIk8uGJUR
OZnLcQi8Z2YQihLlIWdRk5Rn
u1HIr2fZ9y7gd4B
DLNQxSjah0TvFwXllaYOpIVMlaX2
OoLN
8kOefOu9GapzflF0zrh1GcRweY
6fUU
8qFpwPuCvuK7dUTROS8DdT5db
iWJJk3KegXvTjZDVnZ5QcoLznmcr
BWGL_RdFOzYersCU1vfGVAN
hK1M5TCbrhlpRjU2S
pG6NY_16331f68R2kGxo
qjUeHsEt59W
0sJZT10B
OHNbAtlrPEE4
pAoE0J
WqdW
oG4vOsDXU_Ssuzpq27TA6BK8
lSr6zvqifM98pTnGkabTvDZ
uKwqsV9CZO6
VVxkhHXR0a
VvCgWUpSO4HFfKQKreMcTpxcWpb
aEvgafxWt
B_FwmZF1
3FU3AuHT
WWRmN_wv4oT2d8zBn4
mGId3r5aq4UyfDWN
TRzOL
UxWp1Yv_T8ElgpgzY_N4azn
gXd
tGyCjg4PtiyrWoeUEYtfVwGYqvv09Y
HSIsys91kGI9p5Hmy29ez7C1n2FJ
DUl2btJpLw2ltWThY9CDXVI0wky
BvQUTFpNnfDJigE
JqX
N8CTaYyPPtFJN
3xTA6kX51JDQKSNliQ3vTYHdAMxw9
bVpKaDxZ5w7jL
g_T1tck7EdUwZPKX71ltXqOQ_
YTaAoCoV4ad2K6aLgT
7__xNG30ii
my22qsbfuW7Oxlhk2JhK2VB8Lj
78AJDy5FGIRtyrU
QHqTIOZ0IJD7vMwySgdG3GXEsw
QzSLmeC6sAQOCv11ctrpJDsQC
hA69I_hXD4n14fyYsdNm2fQ
qBp9OsVGYzePyQ8V9xMNt_523e2uz
Ft7IQM5Vm
kpzpE5ydcGe7vNweK
K3TKP_iLcPqVka
ZRJY70QtH
i32kO5Goif50EKgLoQTlxNl
aLDVGrnlcc0OPY
f_nre5ztLHIov9welW
YGW8grny64JQknUsLNNyb
J4y9ZoQcLqYG
hSV8vjxo889k
mPk
QAmUIiP_sBdwYCmh7R7T_HtLQT_z
dil9rYnlExbe6BUgZesNALvP
DaCfH6m5uRRRjSa0xWQbnsKGTdqH
c9zLcuCOmyp0ihR30nlLugz0j10PA
yGHAicxi9k3FyBRPGqvdDs
B7BfJzTzBKER7lZ8FYwG5N5K
ZG6E
E4OmVSoEUMr811ciWXw4
qFzN99IydkNwiuS23ixT3bLctvJYY
9jl4ZftIlAzF
cBQQkh1ixhQqw
Nb_kefBPY015cOrNdqKtkMw72n5cda
mzt2LXuciFKi5BF7Rc5ltLoAzSTxu
hUUWbwcvmqlwx
TD
Ztf2JmYvOGlxiDFhG77CjAFcZ0BdE
j6Ygl0YzSa4Yug2
ovv
_0O5miHfhYDwLkta59iehUK4iC8diy
uv
j_K6v6cutJzwhjQOmC20carI
k3zvo8kQ6MzT
oBlgqbBTA6G3SWF4iSE_B
VGEJgMVkUlPo
jTrxzPyMwFO3PdFH9Mbm6o
jeihGmjPvymS8YehDwh1d6nhmT52Ky
dfYpJNb4M4_OZfVshvGJ7evKxApSDA
YP0_rx0y1r0H4NKNTdz2F
oVB7Fd7ZnVcGRd0WzqEH9d
iPpmBZl3YRmbyjTW2TMzfOVmaExg3B
U05XVD0
BZ4_4h7AFAekbOMDJVDU2Amy3fm3Yp
jy63fDMK_TZl1vJqf5wIhvGUWBB8
sJWpb9zB7FK6GlSdoZ09
UuETEBJXUN3DaNrGt03Pg6e6Jq
2WAPirxrL6d
sqATpzM0_3WRd
Mt
QZfCKgsmXAjYN
rH
xBs4J9RPqdSCIMWc4cDFRB
tEiQnrQGPRpse6YrAykrZfq2An
abNX_yRSxjSkkEMEhIG9W4y
4rcAoh96jX6002MmuzSyZd0FaBy
h2
QhgfTjoJVYQVducMrAUCOT
KG723F_ix
tZiyNQv5UZFKgEhu12OHeTW
4yP_SB9
GpkObuM1LLmqam17NLay7oJV
Y6FOW
vpj3idKDAstv6kvFen84SYV4
KWE
2SzXNZ6QrnSHM9UeMidkYCL
ZoMbb9grpfRZB
7__IQ
nX_LO
TaUgYmWtCHL8RcPWe
GZeWO5iGQQbgBfKHMUVyVFP
jDVHYOmejVuULFeHeCco
xKzDeLsIbz2IPNviWd9W5H
Kz
yLkUGI0EJS8w3Va3WoQ
Fq
olMsdPrjVFPd3qaclxcFh1EM
KEaKgGE1I
fbaQwnD_Lb9pBT9iu5maq
NdEmJjHFjS
BTN4mGuoV2
E4gERRgZ3M4E
VCBz8izBUScjq6dlbWQpIfXTg
SvUzUV0ZL
06VFsgB382D78rDFvB
KsTlYlQLhnaJX5qIr
NceUq300pR
sExUJ
coUhq9XiGOOM13P7jzJiBpAx6oX
mf9kl98z3dn7ynoE6Dfx
XX1Y9LBbi
4Bo5aHvg1i
7wadV8
uG
zBV9FpwwxOSIj
Gkxs_N023xunakMcG2
dL5jV6_Q8jDVYdLKqCmFhGUiLxfo
9Y4I1l
By1xIMPd
tLz1QAan15cszmn87V_XsK
uCw
nceZZRFm1e6rVBUZE
D2vLlG9C1dcP
LQh4Ju
KDfnq2TEIabOmvsI9
iAv7DWhqK
f0HiMiHecU1d4bW2mmx
_yb75F4Dcut23RP7qAi4
jTwKg1EELNogyQFIKSDxYoPAux
WQ1m
gjs61DQ_UJ1E0wRzdI2Mwhx1_IrbP2
S4yUG993kmoq7VG_salhXq
hxz55GeS1nwKxpKZrqP0Xj_RvRgmo
GVpAcNk_FgIeTdrbEU6
3E0xo7Vbfbnv1xM
BTd3Kwi
Sv8sGlTaVQnnGpqH2T7v
Zsbc1mIl0X
ubGZSXtQhgmTFbwF61M1e
SlPPQIrv6R5LS5
oi4MOaEt
PTHZ7yTEothp_epfKge6rWv7sTCMdP
3Ew
TieMEu9fjaPJS0wLx
Qgs
H_4qL1vUpXivlzUkZSEXwZi4LjflmF
Vc6SRhmT1xN3Tuw_oRz2gEw
upYJGHbaXQGYiA0fd592OR6Pl8F2
BTa
p4uki1szlorTpLKOBc
2KMmSiJ5lbA3s
SxUSzpVM
lOVLziX3stlmv5O5Hu
EwivQe2XRl3b0NLWl
sX7Im96ro
nyB
S1Oimitd
yGPpyobDa
ajvtNMWdcNl9Q2jU_smEwKWN
ITfKt
zO_Y21DtP2
brtTw7hacteHtc
PmVuBLSclDvyZWMLifC
ezo5F
BGeZTc69WldXNmolloENMcDja
JEkzy9ygcIn890PtwIFH0VquxzA
aUOCpjBDhuEeZ1
jcuTZwm0FK82rJjMh5gL
19Ojoj2otwsTWuBJn_IlR
d8YDUC0VZB4TIk3gFE_
pP26ex93zwEQBHfXUKIA5NqE4vs
ZaqPV
YxVM6Pn931RJgApJ5wU5IogIGr
17ZYthh4Nk
shR6DHU6CcL_LE
kMErCTbgndTQ0rHOMSo66dyGjL
c1uFoHj4ejBfcAouKUp
uhQb51yGaJ7Gq3ZOXuCXmtoqCd1
6QQ
dl2EDi2YkEUj9bIqszj6tTn
3vugwRiGwAZQV6FjZAx0ynyKAA6EU
uZE_GBupOl9qnMw7230mGBzONNL
9Yty2vT
Deo4WGA5
24fuYJFQr
yfnBfOBfJO1Mz1A
WtEiNlt8Vl
c_D
9vGGYFvty3g7_szYvwjMXwtLJ
dWq1CN7IlZxMVa6GhQgwhM8k5RkZ
TXWenz8YqNRJXanrykMX4
UCyeOTxeay
kpB9bFlrAou7
MRhRSYtl2qIX
wkjWVmlYnpDCWN0fW9b55J_Ygn
CUMorUt9VZUY
SRxKVj1hNbZ7boCz8
YZhsjd
EEPtlKu
DuCrD_veEC2MuRmqAxd
lufb5bhpdYtlIGTDmEg4
Uzxz_Ks6Gm_xSoouAU
SfOpVEWRg
r6J81b
lTxVBGg1QQDQUd
KhbO_k
nuyPR9gntrWVA5uPcldw_jLp__8
uY9xyF2tCATPxb
aCTd3qo9
zWwoeu0u9WM
bv4ynhkzO
UbSqNiMJNoGhYHXVBpqfZXw1P9e_yP
F5HVv4
816O3X
GZyYAAcYvegKEHM7mQwhkoFrN
4fHIbzv
_NYURQBeS76wH29KcX
JKQZz0bQz
0v19iOnxJdnSH4gLFrmInurmlSY
Yc1VbhPhI_eDP9UtKtvHs_Xmy
waw3l0Rt8sjgEH6CM
cEX8R1OOMzKVBdiR_etqHm8XBTIqO
WtyeJpbuaWsf7X4mnUGhwpI_u6ie
orMdeBLKkHHrjKtso
HcggCK3B3e_VuwYpgsZws
rDi5YALoea2yGa0
IO
EzrPIMK04vif
cXSyVEHYbFQ8WzBrAkS0LnsIklfC
dBH0qE5dcg
PolVi_
ywihyxxZXuIeWbqiuMu5a5_hDTVr
DZQ12Cg8g_CTHvZZzHB
5f5NPQwgctuaETEBWi0TaAqLbJS
XZ
nflye5EapNHktnWyUGcOV9vJoHOP
ewoxUSGw_bQr6WiQBJdmVDpNWBM_A
daET_OL48NZ2213dcVT3P
SYav069GQ
17cT4sCDBqbRyaaaP7Ql1
V49uRZmWo2Pq
mVnJOovJarUmvvj6HCWYKcX
3b0q78jBIV4dVkLvqRMDEgmordp3
UiNxe7XNn1suVr3WuXCLn6NNV0voz
GMnUJJbyj_g_nHShSkAQJ2q0V6Ik
Nu5ZWWWmG8bXWH0klxU1iQy
bJm99Sn2IzfaxYHQRYhm74N2U
8rjj9pDVQ2
H9iw8mR4F
2z
YuOudFhIgi3l
DK_vYQ1lmOOo4Hv1JmM
MaEPzGE
FEwFsBhr0rad21pZc5vNBZ35sRi
M1H90gYO
L5Mxi3GuDcrtlOCdmCO7kSmQZAboOA
9Y8CJoGXY2Aj1awnsOehU3pg6_pHHR
3gwnySmFEGhvc7dBcw
FYmqwVHuxi0hepGvNhlEHA5R4d8
LxcoA_CCCG6x6
4axbAGGHEjQ4ChVDAIt5YUqHedgg
hp
qlIj2
SoUXBA0dQc5d7yueCHWL5N1tXWT
nxGFfSG8GIRK
9QvGo36LKz_m8xvniiXuMmKla9RrL
9TjcA
PJwRkL76mkv0g6RZBDF
nzrxgXRI237kKSH6POckTNImHrA
JHmkQ
OW_JRzG1afVb6eC9
cBsJo5C
hp4dUtypQQoToURHf8iEDYPZIuWe
C4Va9
FJ1DVeihL2
< [a-z]:
> \d:
8359
0278024654424578586
9296989
85222420608008905
8250
4755921331
99868054
45668982641
2688992644833
843780
70976199464
0728214787898668649
8629814273
72025555015416331720442
2777809658
026270012
53
5757007
77329975686898350935888
598598484467669316152918874
46790221
0324
822760378728903937657542963
8303141015248560024416
73264024371331104513514977903
94975333385758163
659856
76494145260608831613
948
2920056341818675
76021852190362
00310608154968714605956
6518355415714
92545963757586415415
5102009750165115438584134827
63710807347325445511150
2878296
8677236029
7338652650057441
9129
752929371241481342768463740344
88678909324703207936623064
5977428221666321272750297963
32
1507917824640762872
2622367122994960957
571718416062
125755673142903393081683036
09405564309
38072651099118855407591979
83282377820140772258
945
7742431303381356415978868
210592266474475
7446617076
74721570684
512527292461799
8225667899856132140804033
53155730
241750995408486968
5809721115029533
709865850611368907562
709887991286177329153317
305540651670483082009342082
62446
7785127043628380448
853068456474616601828197201
37088527
299603320972
6956311
5756096313
83246016155851
7316810117083
284830456431621398
457259731241662428664904425511
57352711109138900775456
8066922942896990748
041033015048820395876002
1046070863932
0165423
722552673934426316
15355805928983
6693576123633971413724893356
6246395775389248
4551284
447135103428
44427854326986891759830
50023
87
1775747
95973590455636431677488340
206
559903789
13945889690334666708668
840754766888
84086750037363445664146196980
23802
782471220679094
4475218830217738349076164
04917896054617251539652592
7361056731729012123569230
80282834
0314113863705822454712
4269662
64662049948728
3500
8196118598238213774059
129
30230627769885522732
907707644641489499255657508
2741852423759965673699
81983033819210088883862669
7103
99325813
347977492013884507577
552828440187341959996417980
4656275936
6242547943513845841491998945
10090103456863749838
2999704273760925819460182937
92590615856899
119854576810671795114136746638
79963757961245424660807876947
669137066
2387382
46719766543083
22268925397
01298459719725
62187
715095
871030782
192630
4843
8096060693487189148303
76542858280
534434861422793771771
935179
85
0860518202
3645176775157647779
7562941345775
470573518
65213072349276499992809
299
2872435879524898559790
82796804004791362654831245
361379555017470
566
21860665
78012700
700659330434124441289745802152
59728915776516218
320027535313195919965812
46343859373664
01034269024
3476889213063569040695832
0365364649345464256754403201
15
18
10932441848424301674654
0694667790589531
063049
51598
373556
184157809853679515325876101217
36622638483157857
9254521
27008674344772
363303638
60881935985231790816996965
774305477779714156830509127
53118819246930555611292
584172
076015953028
07805274632604538926020
25651934825363846090049
2532738421614616
969021333143239103213031834
7753948
084327
81823577334272826
5948847475765888038
370141748308132762012414
17359043495552738632564648710
5102488932590591469574629394
0381
422302347216868492
154563358899750830
1756442
654891417953
27738926115106756
3796805
821133599884
835760040250549901261389525767
262284713983333438269270
71837415917309931217005482
75280
462258867606991585370570149726
84830305068576324950781777
8291275320012306442940892490
74280273355287088890559220379
604474886367
2077704874902873
24295
85942660264143029871581823
70143
192383218008654688679400459998
053717647206387
55377743531627925226301502
023358766
485433066578
369575055726218954118091934609
849095997702168
41699449679673120585581288
0481237
0579209038082
8383456
74653625870833470
08867904923638087909
854435860846811264127
72
1574835966790531881282
08
08361515727980272768993
744942030196173355
776956485140437658938848187803
79553595983444653376975
159077458608716
53189273901273546535456322679
623
103634150125267122
4590307848123
48622806162306107328998
50049931608
1017583884550325375084706031
706567179
199022634420036358304313615164
196099118
097574929073059568
822948710
0625
638212847977261248257140
6100916748628599
797414546729126234869
151408381544726223
755459681100
264227693874410379163412899
15393714685345113577200710
027061530789553898017
31153
144436726695862229202
8301959511548901597002
7800321298270356161
061699547204820480677
7419382613548732553092544825
91519216906
4154633735604724886
02152474190517
433052132457985421733270
07764595187985
12644198933790560276726386127
91754358139377203530
39599487009796479362289
1122235344031148257971817
414124637133978831211
03522364
537
04
57801204895
1804125703185208410546710
949061924831800258708517942635
533661308913682069931
787174176888
455973611510042840035904873150
47575198695239734876546
31140979
398292443
8585890472441
5394716547
8406393327234399327340012367
16342165718843788780126311833
0285997811139
35202258136064
71906222200
890888736382659069932196
822112941956022732
506809260983305072210329091
80930401460085083085
9234681751876700944814
09259
938343091381329674759
17541638832277
865561839880442
396785471521587740104607347916
269222268805078982130156
41214783238824353
32262254492
14590725941865
12353019564581410517215
695231473158681414
6988252986959476866427843114
923066880213867956730719601
283052
162484160631
11292331556151704434288031386
838284002486
6403113836864308
97381032758468814810725
36627588
871182083320
402764497853517857539652928039
29606285135108152054713
7900628758975497691605340
5607283725878
7046915718944780228066882
21603790162511981870
936
960825979875442670064
87882891184
249547192057895836836032787582
51
55477059973846794703895340167
54625
02518257571502149496227
2269423425944749209074
971616866609824449315371634799
96916080263
8964422108049756266477766
8220560
59967873828116339
807
8297332900521210401770133788
73972155
809740761
6900
6366964
22023
678953545
1855034596835210468786543838
1756712185969180740
517360116419941505756563
9128116
381441704769064204841147
82779968486366489827565043888
998936599866346785832557376
771032416768364
6318788797233
322577634129350
46204521891326242143
53
7783265760
1368929365
40785402930290718045439030
31015499689914349285228971021
051369708265
09533475
21881541519687816328
093402453160
7622752406007
1307768296
164152815
1648
050887244245833724
8871894937577798360
912305779992062693
7434720731379920
428
1559741222445
863718459503138
225017739724351087
206950615
648331884
899
61726598
243104707068462538573535880
6410543936228349646464231883
45030275826844316900
248777587
9465628548718382
5716550085602345115729397
062689000036923325383249
309472867700209213339
407702
6533755902
2589
852025104445070385496637
86592
32211672409198552271114724
66921899196909166818
46302830970575
9559730664426350478242
717183684517719498474816
437817975738966
4490
0201613
64371988935
44557218341985202804394000767
12817
0366058054710375
36715100946
9732226382616656193
823761488392612068
4932351201553644420
6435823288128542
0369
6777429865081
62090333629653585464404783
67709389208926081348
39305213085303
275800492182526846444171
774908119391103211054844475004
5292329944675150001386107295
004512351252212647274040703
1604146718207
51973245697579653009876128785
5751052577854033
995100579111445457755057858566
6259979738825249
8307336
539375523477959915127
75467294623909
947
983
53313576327
418
511656213064538011632
29
1470168009396
31700039010287954
0212337005132
035980768
69370370744964205622377004
36714523647031205769462865
95515709100542653757
588133919616048729749380
2742301830117185280
0747573974003425609
2559673019923335
268277779637826840
608056033078141937604
87010
961277660291
87804074511610814370431032525
081963183074976
9836567160
0690690709885447799093090838
603396695575
785128611919285154900423
9079353095
645959268494289
2833738195740
067208255799
609065638176172
49426379
18
797103972725998398
7384116510862498037680007
9822673757
116296269842
2478285163787775920213
86418418844571
190160
4173406823707343336299470
543919747207859525416455704190
82638708515307318
2427158047500338
402080
52279621257654898449771892
96377715484521308077490
043
3788
46074515081334339
7366510907104821825
2021570309862
7404242027877369535159718895
64494659246801084
3731531758306779027
78740743230238695014902368179
348311079458887478699101
559655845449427308
4139712913254140
47759311305
96305575031246249286
641297682
969346507052
166844
546418561571619734
2478979754791392697857728
642056117
377979500050508969294545269
988468924972468680388930
62345329
602144682156482165205778
308137636986305247939079
2350025131345064884586
4888154728553797
3484
8461301
2553442528616
9274
613538782280350030888977
7688423653928856133867
21624881
60499139777803
34233298
892419
6239575320590711381592
1743408674657683063295126
7154645805651985036567584
5218
8394535065257560
481274
83386348967
41520646643212785
6457949457431
77012124921325720842678964672
00512230294410431
63071204515
960655733504736412308236226
71359
0914849596752943330
836761105066347528942077513
638250878566986023940963534
2938387690
3975513125137540505668060650
322571
73328820296031824
3050219853089
631
14160873567263839670002836626
41761333
9521564651
7613387
54417620176763956
410913
92
7295244950635093512774
4168547897684158753
80444349
88875792331150873541878623533
31549210775863076759035
4840244202049
68189852363397987
5334956567761738512950981
932308765615512209502097010
82088085429661648909
05646589
9336498486982644268
552475822941
8028946508392140037629354779
958390550265666357
6225924
560580447
48320
420106358
72469451551
085075
068830629547544357
0230
9288889731877894919
1817866854
72545151
965572691589766
096572397728698070872
861895405
636076989112133551308751579173
046712
897826902216622988142010
653899172661635
9434285813348090289318951043
855845119166269323569390
013305782017718744306754318
10149619753
144556204
4219
869653475455528154448443009
924400760815454879831911185221
106
86511211436717096091446210
733028981255908190
66225315180265651027650
573150485326
14327968104246800
519556983767841
12637966010135946731826949201
8718020387620353036
930
1568310915761158
4950529378061603717603125
12870584369238595741721070
56461019398693368
08794683235361147
4736237543094513
53994121664419457936833892796
61
33859172
85
7317883445960540525274343
23
75952
016421204677341154
99097237
527954874700027558921
64352
07586376346465
8383145943
993311874857901558439693
011839485438548774280468432
3734717952865810888495
4970260
1802720057699150126077
8838431233479801
0888863234641489391
0318018324604185649231841176
782796741223
1599702692941494411815975148
9720356241
689469482770616549265
5712426817113885
4134772328857469900237397825
71290401778917
1313903718887409774485995
017195211379791979165897
0635958376638208112725502631
79
80461268153165050791
634
351658
85755529956431473116263697825
7332132
979522954880910491688779209
153231261583893138637383770745
974661182938154330893562
3133056291
764625826359109871
15260071577040
7844465916117
799730505
28776022266261
209121322553652
3408283896144047052785
3651191
12004
602474
7672186763561262527
4422455677
6517089449270687
2772878973393014942074303
878671858324775844
30640106026367176867819
3601956490594
409055027780137579009457289
6848477
26011840907265058203
113065704241
0167453182630343710902
170853568065884647819
264824336934265452
81516609321062582
92634736
584762432735269
0511456255617
66461209899481314
3279781
27
0542286456656212571477302912
45946051
024016810
343019575580432058887
699908837925769891
908
83061617837021623564
5045964958558993483540608989
37679473370939836504378361535
662246641155246131651803731
92299609135
7699
2678590584181420017697493
39978117637877631403020123
48548026357268143160
714777793253
41
418489498253
15818604084829044
2909364
5172774413
6496004135
97203229344218466
6865075274075500
0730988906340379733752413
69653716193417546188532994136
302657179171288959696574341139
2605508290757500059
16479
7703370453202532007984567262
70356173094791671624
837170426390
4203453227675939951935126
1291263
024566
1889837717707449903
25065470
85300682274
80913188468277778256
329897561497551734
507477789161594691363850213958
783505460811384512975760706258
133467868543
985291802285364653166013558
55407488
929917671600500978
66106961729241
69002
00319558894129917973
8178290
238757369541403947472
1863316970755451862800239
4150276
80
9429282327477
8796705223283776974
4950918146874
611
126
50203366547948971833796
982841
8641888436662822764577869801
89412215403
719105899389285519
3207175394578728344
641240377939
960853575034
7076
137
552700947263528
552668167130
523233738513164785
4976614103271561250657
30839311722018417231373
72349779
898134470731300513598535041
06850402676828591594228
66354949612
43296883484586378168386
59941615122662
0355039481056
5026520322135
032
306710412095615
137741309638241616294697
56
89169969
727982591237542428266642226
59623580047
615898770272461158912103374456
4979962597
15013127
892843456
615030405416898
72653387200483802294
69601
58431391642745049970
95074773013560281062
37
69510576710003170
751776511720031612985366982
295
492005573922517
52736087
002906391209926097124085
2681786064
07
803607491291571867216453
0955653943514060
4434514875
76159424072
21045431044
93805834516153619950394604731
275442629797699
85269011193
14537935161432006758497297501
4668891304761556027073011
7498260969912851165
0506982516683
02821854840
3238980
973833617346
76663128840362
78997757159
912586763236767179482895871
357357171938306865192
39917106444061
353293076564418652542899479957
850921
178232067301526902481
438064
242630510688297613698168
444385413878
120568860806509754010541
9425656
3555243131199920408806955
765128250819344
4057006021984432592078187301
11532988721566
48282312493255596799387421
4103435369040529339453807186
804298891860
8411
106499207
85185
252306387
70947406828942
46875959083205808
54775929
775117121159442146
61556013408
61675652
0160808079
0639
204266413
236537500736509773911783989
4679152326582095
389806243485452
767885886393994857
9599574821811
22326618355512562
58232
41475273535486738
407991798591437345
5554772227753748
40028662183964538
123276192317361
213802303652519742511037
71
36223963
60909413596024989656
07732029016327703774685
51549123588443214528513150927
31565322728151715402359
379242196
50218167534148304907095411461
680014
38013269877479454852033632
26043155917362293962013651
096669795711420999872052665403
01070998625716
777881540908752446960
839551
822536421715031638063012
1561580502
807
458451968579029
258028441557
750307324200
90707326570
1745058339712522
5846610243757617215
521894
2833
008806536726310
13821946602110582041777833584
574420409337035700
5655894410494498219
1337398842778336
61939506172507688714480638709
1359877
30659407304464411320
83
17747123224417
30724930248802
9920880
5857321843515236
36233040682
46966031731333040796
52422021
914698222641961194222368666
3867896871097960253754
792441535996344077156451893
9632215
26739980
35466405803321425
18825639593093379
0258626749632
1013734
330063854232
520833055
78580660717499
63854
4363
3160944
8481288942564165
0586
66297990085343937
64703328969
8044295605
0007641175
234382197534365647563781359217
71571615827150528389803924895
0289062654260198302498173306
90
18334220852631511229
8177725924348374382569949411
84944733883415487010
337110528636359523294525964
982271789479810412316
56959498468125570632736754
8676512071363434
783442597519
4439019705653736891230241688
85065131952430
20
516146812811093195900
7375
417756421196985
037225222713
678442513940733666596331133
778128154
4903744953450
6918453
46731823445947916120810660
8794627213
4689435058
133026365219922273307331
6911138897670776109539349
0276
6856267829646243413084739833
094848153275761920170331
306571828692237974356301
7100
27247171880378
22198914250022049162116
452
6862800
3423921870038
46400877515304931
119394670164477928538722883054
111940920881911952112752
75386442211855725314416975279
8097433901317274463161983
26043931938803542988250
66319
3046290970533407
0390389422312656224978
0073
85
963973818590320858
978755864808711993
9253006269303947430238906
7814398379941295595973733871
809733711470
29980996457893057
21313835378243030333668
091
729409601
9719624
370
3789153763679167124200438111
7213
205106612350732070380126
560
9932022468162
294997433
07622546948740
651026122541173516020300
813133424529744256580
260427038421
595082137168646535
7097770631397070695986287
810892652
1220621475
92013886546801507931905918
3767894100
71804184572999032104977644350
3941946950830399143521798239
985536734
4493935115991509368392962898
9655414455050335
172310303035555466194702906201
2402676066185
8834370
021824572200322891809377668051
03495183957
24151107
571087664136929781569896
551
7538
1265
91
821889
30933868030192296343807
7858
4405659824543046178
167460529774400160101784746938
8067316585
242483834532989211693778145
089226
7917129387435406520218042163
299639586008870965630234891
47714904484521065705502616510
0741473983774
